#Load packages
library(baseline)
library(prospectr)
library(RColorBrewer)

#Read in data tables (NB set the working directory to where you have the files first!)
all <- read.table("all resins.txt", header = T, row.names = 1)
all.info <- read.table("all resins meta.txt", header = T, row.names = 1)

wavenumbers <- as.numeric(unlist(strsplit(colnames(all), "X"))[seq(2, 2*1764, by = 2)])



#Z-score standardisation
all.stand <- t(scale(t(all)))

#PCA
#Unprocessed spectra
all.pca <- prcomp(all.stand)
#Importance of PCA axes
summary(all.pca)

par(mar = c(4,4,2,1)+0.1)
barplot(summary(all.pca)[[6]][3,1:10],
        ylim = c(0, 1), las = 1, xlab = "PC axes",
        ylab = "Cumulative proportion of variance",
        main = "")
abline(h = 0.9, lty = 2)

#Plot up
all.pca.scores <- as.data.frame(all.pca$x)

plot(all.pca.scores[,1],
     all.pca.scores[,2],
     type = "p", xlab = "", ylab = "",
     las=1, pch = 16,
     col = "red",
     main = "", yaxt = "n", xaxt = "n")

axis(1, lwd = 0, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1)
axis(2, lwd = 0, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1)
title(xlab = "PCA 1", line = 2)
title(ylab = "PCA 2", line = 2)

#text(all.pca.scores[,1],
 #    all.pca.scores[,2], labels = rownames(all.pca.scores), 
   #  cex = 0.5, pos = 1)


#colouration of plots

#install.packages("RColorBrewer")
library("RColorBrewer")
display.brewer.all() #displays all palettes
display.brewer.all(type = "qual", colorblindFriendly = TRUE)

#To select colours for plotting use:
plotting.cols <- brewer.pal(n = 8, name = "Paired")


par(mar = c(6, 5, 4, 8))
plot(all.pca.scores[,1],
     all.pca.scores[,2],
     type = "n", xlab = "PC1 (46.92%)", ylab = "PC2 (21.43%)",
     las=1, 
     main = "")

points(all.pca.scores[all.info$Taxon=="Bid",1],
       all.pca.scores[all.info$Taxon=="Bid",2],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Cun",1],
       all.pca.scores[all.info$Taxon=="Cun",2],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Cor",1],
       all.pca.scores[all.info$Taxon=="Cor",2],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Lan",1],
       all.pca.scores[all.info$Taxon=="Lan",2],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Mac",1],
       all.pca.scores[all.info$Taxon=="Mac",2],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Mont",1],
       all.pca.scores[all.info$Taxon=="Mont",2],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Moor",1],
       all.pca.scores[all.info$Taxon=="Moor",2],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova",1],
       all.pca.scores[all.info$Taxon=="Ova",2],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)


points(all.pca.scores[all.info$Taxon=="Lan_W",1],
       all.pca.scores[all.info$Taxon=="Lan_W",2],
       pch=22, col = "darkgreen", 
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova_W",1],
       all.pca.scores[all.info$Taxon=="Ova_W",2],
       pch=21, col = "brown",      cex = 1.2)

legend("topright",
       inset = c(-0.45, 0),
       legend = c("Ar. bidw.", "Ar. cunn.",
                  "Ag. corb.",  "Ag. lanc.",
                  "Ag. macr.", "Ag. mont.",
                  "Ag. moor", "Ag. ovat.", "Ag.lanc.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21, 22, 21),
       col = c(plotting.cols[1:2], rep("black", 6), "darkgreen", "brown"),
       pt.bg = c(NA, NA, plotting.cols[3:8], NA, NA),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)


par(mar = c(6, 5, 4, 8))
plot(all.pca.scores[,1],
     all.pca.scores[,3],
     type = "n", xlab = "PC1 (46.92%)", ylab = "PC2 (15.65%)",
     las=1, 
     main = "")

points(all.pca.scores[all.info$Taxon=="Bid",1],
       all.pca.scores[all.info$Taxon=="Bid",3],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Cun",1],
       all.pca.scores[all.info$Taxon=="Cun",3],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Cor",1],
       all.pca.scores[all.info$Taxon=="Cor",3],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Lan",1],
       all.pca.scores[all.info$Taxon=="Lan",3],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Mac",1],
       all.pca.scores[all.info$Taxon=="Mac",3],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Mont",1],
       all.pca.scores[all.info$Taxon=="Mont",3],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Moor",1],
       all.pca.scores[all.info$Taxon=="Moor",3],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova",1],
       all.pca.scores[all.info$Taxon=="Ova",3],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Lan_W",1],
       all.pca.scores[all.info$Taxon=="Lan_W",3],
       pch=22, col = "darkgreen", 
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova_W",1],
       all.pca.scores[all.info$Taxon=="Ova_W",3],
       pch=21, col = "brown",      cex = 1.2)

legend("topright",
       inset = c(-0.45, 0),
       legend = c("Ar. bidw.", "Ar. cunn.",
                  "Ag. corb.",  "Ag. lanc.",
                  "Ag. macr.", "Ag. mont.",
                  "Ag. moor", "Ag. ovat.", "Ag.lanc.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21, 22, 21),
       col = c(plotting.cols[1:2], rep("black", 6), "darkgreen", "brown"),
       pt.bg = c(NA, NA, plotting.cols[3:8], NA, NA),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)



par(mar = c(6, 5, 4, 8))
plot(all.pca.scores[,2],
     all.pca.scores[,3],
     type = "n", xlab = "PC2 ", ylab = "PC3",
     las=1, 
     main = "")

points(all.pca.scores[all.info$Taxon=="Bid",2],
       all.pca.scores[all.info$Taxon=="Bid",3],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Cun",2],
       all.pca.scores[all.info$Taxon=="Cun",3],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Cor",2],
       all.pca.scores[all.info$Taxon=="Cor",3],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Lan",2],
       all.pca.scores[all.info$Taxon=="Lan",3],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Mac",2],
       all.pca.scores[all.info$Taxon=="Mac",3],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Mont",2],
       all.pca.scores[all.info$Taxon=="Mont",3],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Moor",2],
       all.pca.scores[all.info$Taxon=="Moor",3],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova",2],
       all.pca.scores[all.info$Taxon=="Ova",3],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Lan_W",2],
       all.pca.scores[all.info$Taxon=="Lan_W",3],
       pch=22, col = "darkgreen", 
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova_W",2],
       all.pca.scores[all.info$Taxon=="Ova_W",3],
       pch=21, col = "brown",      cex = 1.2)

legend("topright",
       inset = c(-0.45, 0),
       legend = c("Ar. bidw.", "Ar. cunn.",
                  "Ag. corb.",  "Ag. lanc.",
                  "Ag. macr.", "Ag. mont.",
                  "Ag. moor", "Ag. ovat.", "Ag.lanc.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21, 22, 21),
       col = c(plotting.cols[1:2], rep("black", 6), "darkgreen", "brown"),
       pt.bg = c(NA, NA, plotting.cols[3:8], NA, NA),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)


par(mar = c(6, 5, 4, 8))
plot(all.pca.scores[,1],
     all.pca.scores[,4],
     type = "n", xlab = "PC1 ", ylab = "PC4 ",
     las=1, 
     main = "")

points(all.pca.scores[all.info$Taxon=="Bid",1],
       all.pca.scores[all.info$Taxon=="Bid",4],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Cun",1],
       all.pca.scores[all.info$Taxon=="Cun",4],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Cor",1],
       all.pca.scores[all.info$Taxon=="Cor",4],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Lan",1],
       all.pca.scores[all.info$Taxon=="Lan",4],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Mac",1],
       all.pca.scores[all.info$Taxon=="Mac",4],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Mont",1],
       all.pca.scores[all.info$Taxon=="Mont",4],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Moor",1],
       all.pca.scores[all.info$Taxon=="Moor",4],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova",1],
       all.pca.scores[all.info$Taxon=="Ova",4],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Lan_W",1],
       all.pca.scores[all.info$Taxon=="Lan_W",4],
       pch=22, col = "darkgreen", 
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova_W",1],
       all.pca.scores[all.info$Taxon=="Ova_W",4],
       pch=21, col = "brown",      cex = 1.2)

legend("topright",
       inset = c(-0.45, 0),
       legend = c("Ar. bidw.", "Ar. cunn.",
                  "Ag. corb.",  "Ag. lanc.",
                  "Ag. macr.", "Ag. mont.",
                  "Ag. moor", "Ag. ovat.", "Ag.lanc.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21, 22, 21),
       col = c(plotting.cols[1:2], rep("black", 6), "darkgreen", "brown"),
       pt.bg = c(NA, NA, plotting.cols[3:8], NA, NA),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)




all.pca.loadings <- as.data.frame(all.pca$rotation)
plot(wavenumbers,
     all.pca.loadings[,1],
     type = "l", xlab = "wavenumbers", ylab = "PC1 loadings",
     las=1,
     main = "", xlim = c(4000, 500))
##This plot shows some baseline drift towards the lower wavenumbers

plot(wavenumbers,
     all.pca.loadings[,2],
     type = "l", xlab = "wavenumbers", ylab = "PC2 loadings",
     las=1,
     main = "", xlim = c(4000, 500))

plot(wavenumbers,
     all.pca.loadings[,3],
     type = "l", xlab = "wavenumbers", ylab = "PC3 loadings",
     las=1,
     main = "", xlim = c(4000, 500))

plot(wavenumbers,
     all.pca.loadings[,4],
     type = "l", xlab = "wavenumbers", ylab = "PC4 loadings",
     las=1,
     main = "", xlim = c(4000, 500))


#Cluster analysis
all.clust <- hclust(dist(all.stand), method = "average")
plot(all.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

#by taxon
plot(all.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = all.info$Taxon)
axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

#by genus
plot(all.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = all.info$Genus)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)



#Taxon mean cluster analysis
all.stand.means <- aggregate(all.stand, by = list(all.info$Taxon),
                                   FUN = mean)
rownames(all.stand.means) <- all.stand.means[,1]
all.stand.means <- all.stand.means[,-1]

all.stand.means.clust <- hclust(dist(all.stand.means), method = "average")
plot(all.stand.means.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

#####
#baseline corrected
#Repeat with baseline correction
#Load packages
library(baseline)

all.base <- baseline(as.matrix(all),
                           method='modpolyfit', deg=2)
all.cor <- getCorrected(all.base)
colnames(all.cor) <- wavenumbers
all.cor <- as.data.frame(all.cor,
                               row.names = rownames(all))

all.cor.stand <- t(scale(t(all.cor)))

#PCA
#Baseline corrected spectra
all.cor.pca <- prcomp(all.cor.stand)
#Importance of PCA axes
summary(all.cor.pca)

par(mar = c(4,4,2,1)+0.1)
barplot(summary(all.cor.pca)[[6]][3,1:10],
        ylim = c(0, 1), las = 1, xlab = "PC axes",
        ylab = "Cumulative proportion of variance",
        main = "")
abline(h = 0.9, lty = 2)


#Plot up
all.cor.pca.scores <- as.data.frame(all.cor.pca$x)

par(mar = c(6, 5, 4, 8))
plot(all.cor.pca.scores[,1],
     all.cor.pca.scores[,2],
     type = "n", xlab = "PC1 (36.35%)", ylab = "PC2 (28.61%)",
     las=1, 
     main = "")

points(all.cor.pca.scores[all.info$Taxon=="Bid",1],
       all.cor.pca.scores[all.info$Taxon=="Bid",2],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Cun",1],
       all.cor.pca.scores[all.info$Taxon=="Cun",2],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Cor",1],
       all.cor.pca.scores[all.info$Taxon=="Cor",2],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Lan",1],
       all.cor.pca.scores[all.info$Taxon=="Lan",2],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Mac",1],
       all.cor.pca.scores[all.info$Taxon=="Mac",2],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Mont",1],
       all.cor.pca.scores[all.info$Taxon=="Mont",2],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Moor",1],
       all.cor.pca.scores[all.info$Taxon=="Moor",2],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Ova",1],
       all.cor.pca.scores[all.info$Taxon=="Ova",2],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)


points(all.cor.pca.scores[all.info$Taxon=="Lan_W",1],
       all.cor.pca.scores[all.info$Taxon=="Lan_W",2],
       pch=22, col = "darkgreen", 
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Ova_W",1],
       all.cor.pca.scores[all.info$Taxon=="Ova_W",2],
       pch=21, col = "brown",      cex = 1.2)

legend("topright",
       inset = c(-0.39, 0),
       legend = c("Ar. bidw.", "Ar. cunn.",
                  "Ag. corb.",  "Ag. lanc.",
                  "Ag. macr.", "Ag. mont.",
                  "Ag. moor", "Ag. ovat.", "Ag. lanc.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21, 22, 21),
       col = c(plotting.cols[1:2], rep("black", 6), "darkgreen", "brown"),
       pt.bg = c(NA, NA, plotting.cols[3:8], NA, NA),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)


par(mar = c(6, 5, 4, 8))
plot(all.cor.pca.scores[,1],
     all.cor.pca.scores[,3],
     type = "n", xlab = "PC1 ", ylab = "PC2",
     las=1, 
     main = "")

points(all.cor.pca.scores[all.info$Taxon=="Bid",1],
       all.cor.pca.scores[all.info$Taxon=="Bid",3],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Cun",1],
       all.cor.pca.scores[all.info$Taxon=="Cun",3],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Cor",1],
       all.cor.pca.scores[all.info$Taxon=="Cor",3],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Lan",1],
       all.cor.pca.scores[all.info$Taxon=="Lan",3],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Mac",1],
       all.cor.pca.scores[all.info$Taxon=="Mac",3],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Mont",1],
       all.cor.pca.scores[all.info$Taxon=="Mont",3],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Moor",1],
       all.cor.pca.scores[all.info$Taxon=="Moor",3],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Ova",1],
       all.cor.pca.scores[all.info$Taxon=="Ova",3],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Lan_W",1],
       all.cor.pca.scores[all.info$Taxon=="Lan_W",3],
       pch=22, col = "darkgreen", 
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Ova_W",1],
       all.cor.pca.scores[all.info$Taxon=="Ova_W",3],
       pch=21, col = "brown",      cex = 1.2)

legend("topright",
       inset = c(-0.45, 0),
       legend = c("Ar. bidw.", "Ar. cunn.",
                  "Ag. corb.",  "Ag. lanc.",
                  "Ag. macr.", "Ag. mont.",
                  "Ag. moor", "Ag. ovat.", "Ag.lanc.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21, 22, 21),
       col = c(plotting.cols[1:2], rep("black", 6), "darkgreen", "brown"),
       pt.bg = c(NA, NA, plotting.cols[3:8], NA, NA),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)



par(mar = c(6, 5, 4, 8))
plot(all.cor.pca.scores[,2],
     all.cor.pca.scores[,3],
     type = "n", xlab = "PC2 ", ylab = "PC3",
     las=1, 
     main = "")

points(all.cor.pca.scores[all.info$Taxon=="Bid",2],
       all.cor.pca.scores[all.info$Taxon=="Bid",3],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Cun",2],
       all.cor.pca.scores[all.info$Taxon=="Cun",3],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Cor",2],
       all.cor.pca.scores[all.info$Taxon=="Cor",3],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Lan",2],
       all.cor.pca.scores[all.info$Taxon=="Lan",3],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Mac",2],
       all.cor.pca.scores[all.info$Taxon=="Mac",3],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Mont",2],
       all.cor.pca.scores[all.info$Taxon=="Mont",3],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Moor",2],
       all.cor.pca.scores[all.info$Taxon=="Moor",3],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Ova",2],
       all.cor.pca.scores[all.info$Taxon=="Ova",3],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Lan_W",2],
       all.cor.pca.scores[all.info$Taxon=="Lan_W",3],
       pch=22, col = "darkgreen", 
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Ova_W",2],
       all.cor.pca.scores[all.info$Taxon=="Ova_W",3],
       pch=21, col = "brown",      cex = 1.2)

legend("topright",
       inset = c(-0.45, 0),
       legend = c("Ar. bidw.", "Ar. cunn.",
                  "Ag. corb.",  "Ag. lanc.",
                  "Ag. macr.", "Ag. mont.",
                  "Ag. moor", "Ag. ovat.", "Ag.lanc.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21, 22, 21),
       col = c(plotting.cols[1:2], rep("black", 6), "darkgreen", "brown"),
       pt.bg = c(NA, NA, plotting.cols[3:8], NA, NA),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)


par(mar = c(6, 5, 4, 8))
plot(all.cor.pca.scores[,1],
     all.cor.pca.scores[,4],
     type = "n", xlab = "PC1 ", ylab = "PC4 ",
     las=1, 
     main = "")

points(all.cor.pca.scores[all.info$Taxon=="Bid",1],
       all.cor.pca.scores[all.info$Taxon=="Bid",4],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Cun",1],
       all.cor.pca.scores[all.info$Taxon=="Cun",4],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Cor",1],
       all.cor.pca.scores[all.info$Taxon=="Cor",4],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Lan",1],
       all.cor.pca.scores[all.info$Taxon=="Lan",4],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Mac",1],
       all.cor.pca.scores[all.info$Taxon=="Mac",4],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Mont",1],
       all.cor.pca.scores[all.info$Taxon=="Mont",4],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Moor",1],
       all.cor.pca.scores[all.info$Taxon=="Moor",4],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Ova",1],
       all.cor.pca.scores[all.info$Taxon=="Ova",4],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)

points(all.cor.pca.scores[all.info$Taxon=="Lan_W",1],
       all.cor.pca.scores[all.info$Taxon=="Lan_W",4],
       pch=22, col = "darkgreen", 
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova_W",1],
       all.pca.scores[all.info$Taxon=="Ova_W",4],
       pch=21, col = "brown",      cex = 1.2)

legend("topright",
       inset = c(-0.45, 0),
       legend = c("Ar. bidw.", "Ar. cunn.",
                  "Ag. corb.",  "Ag. lanc.",
                  "Ag. macr.", "Ag. mont.",
                  "Ag. moor", "Ag. ovat.", "Ag.lanc.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21, 22, 21),
       col = c(plotting.cols[1:2], rep("black", 6), "darkgreen", "brown"),
       pt.bg = c(NA, NA, plotting.cols[3:8], NA, NA),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)



#Loadings on corrected PCA
all.cor.pca.loadings <- as.data.frame(all.cor.pca$rotation)
plot(wavenumbers, all.cor.pca.loadings[,1],
     type = "l", xlab = expression(paste("Wavenumbers cm"^"-1")), ylab = "PC1 loadings",
     las=1, main = "", xlim = c(4000, 500))

plot(wavenumbers, all.cor.pca.loadings[,2],
     type = "l", xlab = expression(paste("Wavenumbers cm"^"-1")), ylab = "PC2 loadings",
     las=1, main = "", xlim = c(4000, 500))

plot(wavenumbers, all.cor.pca.loadings[,3],
     type = "l", xlab = "wavenumbers", ylab = "PC3 loadings",
     las=1, main = "", xlim = c(4000, 500))

plot(wavenumbers, all.cor.pca.loadings[,4],
     type = "l", xlab = "wavenumbers", ylab = "PC4 loadings",
     las=1, main = "", xlim = c(4000, 500))

#Cluster analysis
all.cor.clust <- hclust(dist(all.cor.stand), method = "average")
plot(all.cor.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

plot(all.cor.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = all.info$Taxon)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

plot(all.cor.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = all.info$Genus)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

#plot corrected mean taxon spectra
all.cor.stand.means <- aggregate(all.cor.stand, by = list(all.info$Taxon),
                                       FUN = mean)
rownames(all.cor.stand.means) <- all.cor.stand.means[,1]
all.cor.stand.means <- all.cor.stand.means[,-1]

all.cor.stand.means.clust <- hclust(dist(all.stand.means), method = "average")
plot(all.cor.stand.means.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

#derivatives of spectra

#Z-score standardisation for derivatives
all.stand.m1 <- savitzkyGolay(all.stand, m=1, p=2, w=11)

all.stand.m2 <- savitzkyGolay(all.stand, m=2, p=2, w=11)

#Derivatives

#derivative 1 PCA
#PCA
all.pca <- prcomp(all.stand.m1)
#Importance of PCA axes
summary(all.pca)
par(mar = c(4,4,2,1)+0.1)
barplot(summary(all.pca)[[6]][3,1:10],
        ylim = c(0, 1), las = 1, xlab = "PC axes",
        ylab = "Cumulative proportion of variance",
        main = "")
abline(h = 0.9, lty = 2)

#Plot up
all.pca.scores <- as.data.frame(all.pca$x)

plot(all.pca.scores[,1],
     all.pca.scores[,2],
     type = "p", xlab = "", ylab = "",
     las=1, pch = 16,
     col = "red",
     main = "", yaxt = "n", xaxt = "n")

axis(1, lwd = 0, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1)
axis(2, lwd = 0, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1)
title(xlab = "PCA 1", line = 2)
title(ylab = "PCA 2", line = 2)

# text(all.pca.scores[,1],
# all.pca.scores[,2], labels = rownames(all.pca.scores), 
# cex = 0.5, pos = 1)



##############
#################
##first derivative

par(mar = c(6, 5, 4, 8))
plot(all.pca.scores[,1],
     all.pca.scores[,2],
     type = "n", xlab = "PC1 ", ylab = "PC2",
     las=1, 
     main = "")

points(all.pca.scores[all.info$Taxon=="Bid",1],
       all.pca.scores[all.info$Taxon=="Bid",2],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Cun",1],
       all.pca.scores[all.info$Taxon=="Cun",2],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Cor",1],
       all.pca.scores[all.info$Taxon=="Cor",2],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Lan",1],
       all.pca.scores[all.info$Taxon=="Lan",2],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Mac",1],
       all.pca.scores[all.info$Taxon=="Mac",2],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Mont",1],
       all.pca.scores[all.info$Taxon=="Mont",2],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Moor",1],
       all.pca.scores[all.info$Taxon=="Moor",2],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova",1],
       all.pca.scores[all.info$Taxon=="Ova",2],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)


points(all.pca.scores[all.info$Taxon=="Lan_W",1],
       all.pca.scores[all.info$Taxon=="Lan_W",2],
       pch=22, col = "darkgreen", 
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova_W",1],
       all.pca.scores[all.info$Taxon=="Ova_W",2],
       pch=21, col = "brown",      cex = 1.2)

legend("topright",
       inset = c(-0.42, 0),
       legend = c("Ar. bidw.", "Ar. cunn.",
                  "Ag. corb.",  "Ag. lanc.",
                  "Ag. macr.", "Ag. mont.",
                  "Ag. moor", "Ag. ovat.", "Ag. lanc.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21, 22, 21),
       col = c(plotting.cols[1:2], rep("black", 6), "darkgreen", "brown"),
       pt.bg = c(NA, NA, plotting.cols[3:8], NA, NA),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)


par(mar = c(6, 5, 4, 8))
plot(all.pca.scores[,1],
     all.pca.scores[,3],
     type = "n", xlab = "PC1 ", ylab = "PC3",
     las=1, 
     main = "")

points(all.pca.scores[all.info$Taxon=="Bid",1],
       all.pca.scores[all.info$Taxon=="Bid",3],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Cun",1],
       all.pca.scores[all.info$Taxon=="Cun",3],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Cor",1],
       all.pca.scores[all.info$Taxon=="Cor",3],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Lan",1],
       all.pca.scores[all.info$Taxon=="Lan",3],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Mac",1],
       all.pca.scores[all.info$Taxon=="Mac",3],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Mont",1],
       all.pca.scores[all.info$Taxon=="Mont",3],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Moor",1],
       all.pca.scores[all.info$Taxon=="Moor",3],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova",1],
       all.pca.scores[all.info$Taxon=="Ova",3],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Lan_W",1],
       all.pca.scores[all.info$Taxon=="Lan_W",3],
       pch=22, col = "darkgreen", 
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova_W",1],
       all.pca.scores[all.info$Taxon=="Ova_W",3],
       pch=21, col = "brown",      cex = 1.2)

legend("topright",
       inset = c(-0.31, 0),
       legend = c("Ar. bidw.", "Ar. cunn.",
                  "Ag. corb.",  "Ag. lanc.",
                  "Ag. macr.", "Ag. mont.",
                  "Ag. moor", "Ag. ovat.", "Ag.lanc.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21, 22, 21),
       col = c(plotting.cols[1:2], rep("black", 6), "darkgreen", "brown"),
       pt.bg = c(NA, NA, plotting.cols[3:8], NA, NA),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)



par(mar = c(6, 5, 4, 8))
plot(all.pca.scores[,2],
     all.pca.scores[,3],
     type = "n", xlab = "PC2 ", ylab = "PC3",
     las=1, 
     main = "")

points(all.pca.scores[all.info$Taxon=="Bid",2],
       all.pca.scores[all.info$Taxon=="Bid",3],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Cun",2],
       all.pca.scores[all.info$Taxon=="Cun",3],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Cor",2],
       all.pca.scores[all.info$Taxon=="Cor",3],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Lan",2],
       all.pca.scores[all.info$Taxon=="Lan",3],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Mac",2],
       all.pca.scores[all.info$Taxon=="Mac",3],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Mont",2],
       all.pca.scores[all.info$Taxon=="Mont",3],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Moor",2],
       all.pca.scores[all.info$Taxon=="Moor",3],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova",2],
       all.pca.scores[all.info$Taxon=="Ova",3],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Lan_W",2],
       all.pca.scores[all.info$Taxon=="Lan_W",3],
       pch=22, col = "darkgreen", 
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova_W",2],
       all.pca.scores[all.info$Taxon=="Ova_W",3],
       pch=21, col = "brown",      cex = 1.2)

legend("topright",
       inset = c(-0.31, 0),
       legend = c("Ar. bidw.", "Ar. cunn.",
                  "Ag. corb.",  "Ag. lanc.",
                  "Ag. macr.", "Ag. mont.",
                  "Ag. moor", "Ag. ovat.", "Ag.lanc.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21, 22, 21),
       col = c(plotting.cols[1:2], rep("black", 6), "darkgreen", "brown"),
       pt.bg = c(NA, NA, plotting.cols[3:8], NA, NA),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)


par(mar = c(6, 5, 4, 8))
plot(all.pca.scores[,1],
     all.pca.scores[,4],
     type = "n", xlab = "PC1 ", ylab = "PC4 ",
     las=1, 
     main = "")

points(all.pca.scores[all.info$Taxon=="Bid",1],
       all.pca.scores[all.info$Taxon=="Bid",4],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Cun",1],
       all.pca.scores[all.info$Taxon=="Cun",4],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Cor",1],
       all.pca.scores[all.info$Taxon=="Cor",4],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Lan",1],
       all.pca.scores[all.info$Taxon=="Lan",4],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Mac",1],
       all.pca.scores[all.info$Taxon=="Mac",4],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Mont",1],
       all.pca.scores[all.info$Taxon=="Mont",4],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Moor",1],
       all.pca.scores[all.info$Taxon=="Moor",4],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova",1],
       all.pca.scores[all.info$Taxon=="Ova",4],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Lan_W",1],
       all.pca.scores[all.info$Taxon=="Lan_W",4],
       pch=22, col = "darkgreen", 
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova_W",1],
       all.pca.scores[all.info$Taxon=="Ova_W",4],
       pch=21, col = "brown",      cex = 1.2)

legend("topright",
       inset = c(-0.31, 0),
       legend = c("Ar. bidw.", "Ar. cunn.",
                  "Ag. corb.",  "Ag. lanc.",
                  "Ag. macr.", "Ag. mont.",
                  "Ag. moor", "Ag. ovat.", "Ag.lanc.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21, 22, 21),
       col = c(plotting.cols[1:2], rep("black", 6), "darkgreen", "brown"),
       pt.bg = c(NA, NA, plotting.cols[3:8], NA, NA),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)

############
############

par(mar = c(4,4,2,1)+0.1)
barplot(summary(all.pca)[[6]][3,1:10],
        ylim = c(0, 1), las = 1, xlab = "PC axes",
        ylab = "Cumulative proportion of variance",
        main = "")
abline(h = 0.9, lty = 2)



#second derivative
#PCA
all.pca <- prcomp(all.stand.m2)
#Importance of PCA axes
summary(all.pca)

par(mar = c(4,4,2,1)+0.1)
barplot(summary(all.pca)[[6]][3,1:10],
        ylim = c(0, 1), las = 1, xlab = "PC axes",
        ylab = "Cumulative proportion of variance",
        main = "")
abline(h = 0.9, lty = 2)

#Plot up
all.pca.scores <- as.data.frame(all.pca$x)

par(mar = c(6, 5, 4, 8))
plot(all.pca.scores[,1],
     all.pca.scores[,2],
     type = "n", xlab = "PC1 ", ylab = "PC2",
     las=1, 
     main = "")

points(all.pca.scores[all.info$Taxon=="Bid",1],
       all.pca.scores[all.info$Taxon=="Bid",2],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Cun",1],
       all.pca.scores[all.info$Taxon=="Cun",2],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Cor",1],
       all.pca.scores[all.info$Taxon=="Cor",2],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Lan",1],
       all.pca.scores[all.info$Taxon=="Lan",2],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Mac",1],
       all.pca.scores[all.info$Taxon=="Mac",2],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Mont",1],
       all.pca.scores[all.info$Taxon=="Mont",2],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Moor",1],
       all.pca.scores[all.info$Taxon=="Moor",2],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova",1],
       all.pca.scores[all.info$Taxon=="Ova",2],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)


points(all.pca.scores[all.info$Taxon=="Lan_W",1],
       all.pca.scores[all.info$Taxon=="Lan_W",2],
       pch=22, col = "darkgreen", 
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova_W",1],
       all.pca.scores[all.info$Taxon=="Ova_W",2],
       pch=21, col = "brown",      cex = 1.2)

legend("topright",
       inset = c(-0.40, 0),
       legend = c("Ar. bidw.", "Ar. cunn.",
                  "Ag. corb.",  "Ag. lanc.",
                  "Ag. macr.", "Ag. mont.",
                  "Ag. moor", "Ag. ovat.", "Ag. lanc.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21, 22, 21),
       col = c(plotting.cols[1:2], rep("black", 6), "darkgreen", "brown"),
       pt.bg = c(NA, NA, plotting.cols[3:8], NA, NA),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)


par(mar = c(6, 5, 4, 8))
plot(all.pca.scores[,1],
     all.pca.scores[,3],
     type = "n", xlab = "PC1 ", ylab = "PC3",
     las=1, 
     main = "")

points(all.pca.scores[all.info$Taxon=="Bid",1],
       all.pca.scores[all.info$Taxon=="Bid",3],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Cun",1],
       all.pca.scores[all.info$Taxon=="Cun",3],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Cor",1],
       all.pca.scores[all.info$Taxon=="Cor",3],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Lan",1],
       all.pca.scores[all.info$Taxon=="Lan",3],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Mac",1],
       all.pca.scores[all.info$Taxon=="Mac",3],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Mont",1],
       all.pca.scores[all.info$Taxon=="Mont",3],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Moor",1],
       all.pca.scores[all.info$Taxon=="Moor",3],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova",1],
       all.pca.scores[all.info$Taxon=="Ova",3],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Lan_W",1],
       all.pca.scores[all.info$Taxon=="Lan_W",3],
       pch=22, col = "darkgreen", 
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova_W",1],
       all.pca.scores[all.info$Taxon=="Ova_W",3],
       pch=21, col = "brown",      cex = 1.2)

legend("topright",
       inset = c(-0.40, 0),
       legend = c("Ar. bidw.", "Ar. cunn.",
                  "Ag. corb.",  "Ag. lanc.",
                  "Ag. macr.", "Ag. mont.",
                  "Ag. moor", "Ag. ovat.", "Ag. lanc.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21, 22, 21),
       col = c(plotting.cols[1:2], rep("black", 6), "darkgreen", "brown"),
       pt.bg = c(NA, NA, plotting.cols[3:8], NA, NA),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)



par(mar = c(6, 5, 4, 8))
plot(all.pca.scores[,2],
     all.pca.scores[,3],
     type = "n", xlab = "PC2 ", ylab = "PC3",
     las=1, 
     main = "")

points(all.pca.scores[all.info$Taxon=="Bid",2],
       all.pca.scores[all.info$Taxon=="Bid",3],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Cun",2],
       all.pca.scores[all.info$Taxon=="Cun",3],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Cor",2],
       all.pca.scores[all.info$Taxon=="Cor",3],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Lan",2],
       all.pca.scores[all.info$Taxon=="Lan",3],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Mac",2],
       all.pca.scores[all.info$Taxon=="Mac",3],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Mont",2],
       all.pca.scores[all.info$Taxon=="Mont",3],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Moor",2],
       all.pca.scores[all.info$Taxon=="Moor",3],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova",2],
       all.pca.scores[all.info$Taxon=="Ova",3],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Lan_W",2],
       all.pca.scores[all.info$Taxon=="Lan_W",3],
       pch=22, col = "darkgreen", 
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova_W",2],
       all.pca.scores[all.info$Taxon=="Ova_W",3],
       pch=21, col = "brown",      cex = 1.2)

legend("topright",
       inset = c(-0.31, 0),
       legend = c("Ar. bidw.", "Ar. cunn.",
                  "Ag. corb.",  "Ag. lanc.",
                  "Ag. macr.", "Ag. mont.",
                  "Ag. moor", "Ag. ovat.", "Ag.lanc.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21, 22, 21),
       col = c(plotting.cols[1:2], rep("black", 6), "darkgreen", "brown"),
       pt.bg = c(NA, NA, plotting.cols[3:8], NA, NA),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)


par(mar = c(6, 5, 4, 8))
plot(all.pca.scores[,1],
     all.pca.scores[,4],
     type = "n", xlab = "PC1 ", ylab = "PC4 ",
     las=1, 
     main = "")

points(all.pca.scores[all.info$Taxon=="Bid",1],
       all.pca.scores[all.info$Taxon=="Bid",4],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Cun",1],
       all.pca.scores[all.info$Taxon=="Cun",4],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Cor",1],
       all.pca.scores[all.info$Taxon=="Cor",4],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Lan",1],
       all.pca.scores[all.info$Taxon=="Lan",4],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Mac",1],
       all.pca.scores[all.info$Taxon=="Mac",4],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Mont",1],
       all.pca.scores[all.info$Taxon=="Mont",4],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Moor",1],
       all.pca.scores[all.info$Taxon=="Moor",4],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova",1],
       all.pca.scores[all.info$Taxon=="Ova",4],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Lan_W",1],
       all.pca.scores[all.info$Taxon=="Lan_W",4],
       pch=22, col = "darkgreen", 
       cex = 1.2)

points(all.pca.scores[all.info$Taxon=="Ova_W",1],
       all.pca.scores[all.info$Taxon=="Ova_W",4],
       pch=21, col = "brown",      cex = 1.2)

legend("topright",
       inset = c(-0.31, 0),
       legend = c("Ar. bidw.", "Ar. cunn.",
                  "Ag. corb.",  "Ag. lanc.",
                  "Ag. macr.", "Ag. mont.",
                  "Ag. moor", "Ag. ovat.", "Ag.lanc.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21, 22, 21),
       col = c(plotting.cols[1:2], rep("black", 6), "darkgreen", "brown"),
       pt.bg = c(NA, NA, plotting.cols[3:8], NA, NA),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)




#first derivative
#Cluster analysis
all.clust <- hclust(dist(all.stand.m1), method = "average")
plot(all.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

plot(all.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = all.info$Taxon)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

plot(all.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = all.info$Genus)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

#second derivative
#Cluster analysis
all.clust <- hclust(dist(all.stand.m2), method = "average")
plot(all.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

plot(all.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = all.info$Taxon)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

plot(all.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = all.info$Genus)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

#Taxon mean cluster analysis
#first derivative
all.stand.m1.means <- aggregate(all.stand.m1, by = list(all.info$Taxon),
                                      FUN = mean)
rownames(all.stand.m1.means) <- all.stand.m1.means[,1]
all.stand.m1.means <- all.stand.m1.means[,-1]

all.stand.m1.means.clust <- hclust(dist(all.stand.m1.means), method = "average")
plot(all.stand.m1.means.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)


#Taxon mean cluster analysis
#second derivative
all.stand.m2.means <- aggregate(all.stand.m2, by = list(all.info$Taxon),
                                      FUN = mean)
rownames(all.stand.m2.means) <- all.stand.m2.means[,1]
all.stand.m2.means <- all.stand.m2.means[,-1]

all.stand.m2.means.clust <- hclust(dist(all.stand.m2.means), method = "average")
plot(all.stand.m2.means.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

