#Load packages
library(baseline)
library(prospectr)
library(RColorBrewer)

#Read in data tables 
arboretum <- read.table("arboretum.txt", header = T, row.names = 1)
arboretum.info <- read.table("arboretum meta.txt", header = T, row.names = 1)

wavenumbers <- as.numeric(unlist(strsplit(colnames(arboretum), "X"))[seq(2, 2*1764, by = 2)])

#Z-score standardisation
arboretum.stand <- t(scale(t(arboretum)))

#PCA
#Unprocessed spectra
arboretum.pca <- prcomp(arboretum.stand)
#Importance of PCA axes
summary(arboretum.pca)

par(mar = c(4,4,2,1)+0.1)
barplot(summary(arboretum.pca)[[6]][3,1:10],
        ylim = c(0, 1), las = 1, xlab = "PC axes",
        ylab = "Cumulative proportion of variance",
        main = "")
abline(h = 0.9, lty = 2)

#Plot up
arboretum.pca.scores <- as.data.frame(arboretum.pca$x)

#PCA with sample names added
plot(arboretum.pca.scores[,1],
     arboretum.pca.scores[,2],
     type = "p", xlab = "", ylab = "",
     las=1, pch = 16,
     col = "red",
     main = "", yaxt = "n", xaxt = "n")

axis(1, lwd = 0, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1)
axis(2, lwd = 0, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1)
title(xlab = "PCA 1 (50.49%)", line = 2)
title(ylab = "PCA 2 (22.01%)", line = 2)

text(arboretum.pca.scores[,1], 
     arboretum.pca.scores[,2],
     labels = rownames(arboretum.pca.scores),
     cex = 0.5, pos = 1)



#install.packages("RColorBrewer")
library("RColorBrewer")
display.brewer.all() #displays all palettes
display.brewer.all(type = "qual", colorblindFriendly = TRUE)

#To select colours for plotting use:
plotting.cols <- brewer.pal(n = 8, name = "Paired")

#PCA with coloured symbols, PC1 vs PC2, labels outside plot
par(mar = c(6, 5, 4, 8))

plot(arboretum.pca.scores[,1],
     arboretum.pca.scores[,2],
     type = "n", xlab = "PC1 (50.49%)", ylab = "PC2 (22.01%)",
     las=1, 
     main = "")

points(arboretum.pca.scores[arboretum.info$Taxon=="Bid",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Bid",2],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cun",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Cun",2],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cor",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Cor",2],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Lan",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Lan",2],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mac",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Mac",2],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mont",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Mont",2],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Moor",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Moor",2],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Ova",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Ova",2],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)


legend("topright",
       inset = c(-0.55, 0),
       legend = c("Ar. bidwilli", "Ar. cunninghamii",
                  "Ag. corbassonii",  "Ag. lanceolata",
                  "Ag. macrophylla", "Ag. montana",
                  "Ag. moorei", "Ag. ovata"),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21),
       col = c(plotting.cols[1:2], rep("black", 6)),
       pt.bg = c(NA, NA, plotting.cols[3:8]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)


#PCA with coloured symbols, PC1 vs PC3, labels outside plot
par(mar = c(6, 5, 4, 8))
plot(arboretum.pca.scores[,1],
     arboretum.pca.scores[,3],
     type = "n", xlab = "PC1 (50.49%)", ylab = "PC3 (13.17%)",
     las=1, 
     main = "")

points(arboretum.pca.scores[arboretum.info$Taxon=="Bid",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Bid",3],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cun",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Cun",3],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cor",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Cor",3],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Lan",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Lan",3],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mac",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Mac",3],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mont",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Mont",3],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Moor",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Moor",3],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Ova",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Ova",3],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)


legend("topright",
       inset = c(-0.55, 0),
       legend = c("Ar. bidwilli", "Ar. cunninghamii",
                  "Ag. corbassonii",  "Ag. lanceolata",
                  "Ag. macrophylla", "Ag. montana",
                  "Ag. moorei", "Ag. ovata"),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21),
       col = c(plotting.cols[1:2], rep("black", 6)),
       pt.bg = c(NA, NA, plotting.cols[3:8]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)

#PCA with coloured symbols, PC2 vs PC3, labels outside plot
par(mar = c(6, 5, 4, 8))
plot(arboretum.pca.scores[,2],
     arboretum.pca.scores[,3],
     type = "n", xlab = "PC2 (22.01%)", ylab = "PC3 (13.17%)",
     las=1, 
     main = "")

points(arboretum.pca.scores[arboretum.info$Taxon=="Bid",2],
       arboretum.pca.scores[arboretum.info$Taxon=="Bid",3],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cun",2],
       arboretum.pca.scores[arboretum.info$Taxon=="Cun",3],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cor",2],
       arboretum.pca.scores[arboretum.info$Taxon=="Cor",3],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Lan",2],
       arboretum.pca.scores[arboretum.info$Taxon=="Lan",3],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mac",2],
       arboretum.pca.scores[arboretum.info$Taxon=="Mac",3],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mont",2],
       arboretum.pca.scores[arboretum.info$Taxon=="Mont",3],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Moor",2],
       arboretum.pca.scores[arboretum.info$Taxon=="Moor",3],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Ova",2],
       arboretum.pca.scores[arboretum.info$Taxon=="Ova",3],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)


legend("topright",
       inset = c(-0.55, 0),
       legend = c("Ar. bidwilli", "Ar. cunninghamii",
                  "Ag. corbassonii",  "Ag. lanceolata",
                  "Ag. macrophylla", "Ag. montana",
                  "Ag. moorei", "Ag. ovata"),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21),
       col = c(plotting.cols[1:2], rep("black", 6)),
       pt.bg = c(NA, NA, plotting.cols[3:8]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)

#PCA with coloured symbols, PC1 vs PC4, labels outside plot
par(mar = c(6, 5, 4, 8))
plot(arboretum.pca.scores[,1],
     arboretum.pca.scores[,4],
     type = "n", xlab = "PC1 (50.49%)", ylab = "PC4 (5.14%)",
     las=1, 
     main = "")

points(arboretum.pca.scores[arboretum.info$Taxon=="Bid",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Bid",4],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cun",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Cun",4],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cor",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Cor",4],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Lan",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Lan",4],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mac",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Mac",4],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mont",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Mont",4],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Moor",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Moor",4],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Ova",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Ova",4],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)


legend("topright",
       inset = c(-0.55, 0),
       legend = c("Ar. bidwilli", "Ar. cunninghamii",
                  "Ag. corbassonii",  "Ag. lanceolata",
                  "Ag. macrophylla", "Ag. montana",
                  "Ag. moorei", "Ag. ovata"),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21),
       col = c(plotting.cols[1:2], rep("black", 6)),
       pt.bg = c(NA, NA, plotting.cols[3:8]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)


#loadings on the PC axes
arboretum.pca.loadings <- as.data.frame(arboretum.pca$rotation)
plot(wavenumbers,
     arboretum.pca.loadings[,1],
     type = "l", xlab = "wavenumbers", ylab = "PC1 loadings",
     las=1,
     main = "", xlim = c(4000, 500))
##This plot shows some baseline drift towards the lower wavenumbers
#so baseline correction is necessary

plot(wavenumbers,
     arboretum.pca.loadings[,2],
     type = "l", xlab = "wavenumbers", ylab = "PC2 loadings",
     las=1,
     main = "", xlim = c(4000, 500))

plot(wavenumbers,
     arboretum.pca.loadings[,3],
     type = "l", xlab = "wavenumbers", ylab = "PC3 loadings",
     las=1,
     main = "", xlim = c(4000, 500))
##Again, there's some baseline effect here

plot(wavenumbers,
     arboretum.pca.loadings[,4],
     type = "l", xlab = "wavenumbers", ylab = "PC4 loadings",
     las=1,
     main = "", xlim = c(4000, 500))


#Cluster analysis
#cluster analysis with sample labels
arboretum.clust <- hclust(dist(arboretum.stand), method = "average")
plot(arboretum.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

#by taxon
plot(arboretum.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = arboretum.info$Taxon)
axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

#by genus
plot(arboretum.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = arboretum.info$Genus)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)



#Taxon mean cluster analysis
arboretum.stand.means <- aggregate(arboretum.stand, by = list(arboretum.info$Taxon),
                                   FUN = mean)
rownames(arboretum.stand.means) <- arboretum.stand.means[,1]
arboretum.stand.means <- arboretum.stand.means[,-1]

arboretum.stand.means.clust <- hclust(dist(arboretum.stand.means), method = "average")
plot(arboretum.stand.means.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

#####
#baseline corrected
#Repeat with baseline correction

arboretum.base <- baseline(as.matrix(arboretum),
                           method='modpolyfit', deg=2)
arboretum.cor <- getCorrected(arboretum.base)
colnames(arboretum.cor) <- wavenumbers
arboretum.cor <- as.data.frame(arboretum.cor,
                               row.names = rownames(arboretum))

arboretum.cor.stand <- t(scale(t(arboretum.cor)))

#PCA
#Baseline corrected spectra
arboretum.cor.pca <- prcomp(arboretum.cor.stand)
#Importance of PCA axes
summary(arboretum.cor.pca)

par(mar = c(4,4,2,1)+0.1)
barplot(summary(arboretum.cor.pca)[[6]][3,1:10],
        ylim = c(0, 1), las = 1, xlab = "PC axes",
        ylab = "Cumulative proportion of variance",
        main = "")
abline(h = 0.9, lty = 2)

########
#PCA with sample names added
plot(arboretum.cor.pca.scores[,1],
     arboretum.cor.pca.scores[,2],
     type = "p", xlab = "", ylab = "",
     las=1, pch = 16,
     col = "red",
     main = "", yaxt = "n", xaxt = "n")

axis(1, lwd = 0, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1)
axis(2, lwd = 0, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1)
title(xlab = "PCA 1 (50.49%)", line = 2)
title(ylab = "PCA 2 (22.01%)", line = 2)

text(arboretum.cor.pca.scores[,1], 
     arboretum.cor.pca.scores[,2],
     labels = rownames(arboretum.pca.scores),
     cex = 0.5, pos = 1)
############################################

#Plot up
#baseline corrected PCA, PC1 vs PC2, with colours, label outside plot
arboretum.cor.pca.scores <- as.data.frame(arboretum.cor.pca$x)

par(mar = c(6, 5, 4, 8))
plot(arboretum.cor.pca.scores[,1],
     arboretum.cor.pca.scores[,2],
     type = "n", xlab = "PC1 (38.2%) ", ylab = "PC2 (28.75%)",
     las=1, 
     main = "")

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Bid",1],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Bid",2],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Cun",1],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Cun",2],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Cor",1],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Cor",2],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Lan",1],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Lan",2],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Mac",1],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Mac",2],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Mont",1],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Mont",2],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Moor",1],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Moor",2],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Ova",1],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Ova",2],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)


legend("topright",
       inset = c(-0.55, 0),
       legend = c("Ar. bidwilli", "Ar. cunninghamii",
                  "Ag. corbassonii",  "Ag. lanceolata",
                  "Ag. macrophylla", "Ag. montana",
                  "Ag. moorei", "Ag. ovata"),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21),
       col = c(plotting.cols[1:2], rep("black", 6)),
       pt.bg = c(NA, NA, plotting.cols[3:8]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)

#baseline corrected PCA, PC1 vs PC2, with colours, shorter label outside plot
arboretum.cor.pca.scores <- as.data.frame(arboretum.cor.pca$x)

par(mar = c(6, 5, 4, 8))
plot(arboretum.cor.pca.scores[,1],
     arboretum.cor.pca.scores[,2],
     type = "n", xlab = "PC1 (38.2%) ", ylab = "PC2 (28.75%)",
     las=1, 
     main = "")

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Bid",1],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Bid",2],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Cun",1],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Cun",2],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Cor",1],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Cor",2],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Lan",1],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Lan",2],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Mac",1],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Mac",2],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Mont",1],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Mont",2],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Moor",1],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Moor",2],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Ova",1],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Ova",2],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)


legend("topright",
       inset = c(-0.35, 0),
       legend = c("Ar. bidw.", "Ar. cunn.",
                  "Ag. corb.",  "Ag. lanc.",
                  "Ag. macr.", "Ag. mont.",
                  "Ag. moor", "Ag. ovat."),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21),
       col = c(plotting.cols[1:2], rep("black", 6)),
       pt.bg = c(NA, NA, plotting.cols[3:8]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)


#baseline corrected PCA, PC1 vs PC3, with colours, label outside plot
arboretum.cor.pca.scores <- as.data.frame(arboretum.cor.pca$x)

par(mar = c(6, 5, 4, 8))

plot(arboretum.cor.pca.scores[,1],
     arboretum.cor.pca.scores[,3],
     type = "n", xlab = "PC1 (38.2%)", ylab = "PC3 (12.7%) ",
     las=1, 
     main = "")

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Bid",1],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Bid",3],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Cun",1],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Cun",3],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Cor",1],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Cor",3],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Lan",1],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Lan",3],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Mac",1],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Mac",3],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Mont",1],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Mont",3],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Moor",1],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Moor",3],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Ova",1],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Ova",3],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)


legend("topright",
       inset = c(-0.55, 0),
       legend = c("Ar. bidwilli", "Ar. cunninghamii",
                  "Ag. corbassonii",  "Ag. lanceolata",
                  "Ag. macrophylla", "Ag. montana",
                  "Ag. moorei", "Ag. ovata"),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21),
       col = c(plotting.cols[1:2], rep("black", 6)),
       pt.bg = c(NA, NA, plotting.cols[3:8]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)


#baseline corrected PCA, PC2 vs PC3, with colours, label outside plot
arboretum.cor.pca.scores <- as.data.frame(arboretum.cor.pca$x)

par(mar = c(6, 5, 4, 8))

plot(arboretum.cor.pca.scores[,2],
     arboretum.cor.pca.scores[,3],
     type = "n", xlab = "PC2 (27.8%)", ylab = "PC3 (12.7%) ",
     las=1, 
     main = "")

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Bid",2],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Bid",3],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Cun",2],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Cun",3],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Cor",2],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Cor",3],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Lan",2],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Lan",3],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Mac",2],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Mac",3],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Mont",2],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Mont",3],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Moor",2],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Moor",3],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(arboretum.cor.pca.scores[arboretum.info$Taxon=="Ova",2],
       arboretum.cor.pca.scores[arboretum.info$Taxon=="Ova",3],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)


legend("topright",
       inset = c(-0.55, 0),
       legend = c("Ar. bidwilli", "Ar. cunninghamii",
                  "Ag. corbassonii",  "Ag. lanceolata",
                  "Ag. macrophylla", "Ag. montana",
                  "Ag. moorei", "Ag. ovata"),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21),
       col = c(plotting.cols[1:2], rep("black", 6)),
       pt.bg = c(NA, NA, plotting.cols[3:8]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)

#Loadings on baseline corrected PCs
par(mar = c(4,4,2,1)+0.1)
arboretum.cor.pca.loadings <- as.data.frame(arboretum.cor.pca$rotation)
plot(wavenumbers, arboretum.cor.pca.loadings[,1],
     type = "l", xlab = expression(paste("Wavenumbers cm"^"-1")), ylab = "PC1 loadings",
     las=1, main = "", xlim = c(4000, 500))

plot(wavenumbers, arboretum.cor.pca.loadings[,2],
     type = "l", xlab = expression(paste("Wavenumbers cm"^"-1")), ylab = "PC2 loadings",
     las=1, main = "", xlim = c(4000, 500))

plot(wavenumbers, arboretum.cor.pca.loadings[,3],
     type = "l", xlab = "wavenumbers", ylab = "PC3 loadings",
     las=1, main = "", xlim = c(4000, 500))

plot(wavenumbers, arboretum.cor.pca.loadings[,4],
     type = "l", xlab = "wavenumbers", ylab = "PC4 loadings",
     las=1, main = "", xlim = c(4000, 500))

#Cluster analysis
#baseline corrected cluster analysis
#samples named
arboretum.cor.clust <- hclust(dist(arboretum.cor.stand), method = "average")
plot(arboretum.cor.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

#by taxon
plot(arboretum.cor.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = arboretum.info$Taxon)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

#by genus
plot(arboretum.cor.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = arboretum.info$Genus)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

#plot corrected taxon mean spectra
arboretum.cor.stand.means <- aggregate(arboretum.cor.stand, by = list(arboretum.info$Taxon),
                                   FUN = mean)
rownames(arboretum.cor.stand.means) <- arboretum.cor.stand.means[,1]
arboretum.cor.stand.means <- arboretum.cor.stand.means[,-1]

arboretum.cor.stand.means.clust <- hclust(dist(arboretum.stand.means), method = "average")
plot(arboretum.cor.stand.means.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

#######derivatives to explore PCA further
#derivatives of spectra

#Z-score standardisation for derivatives


arboretum.stand.m1 <- savitzkyGolay(arboretum.stand, m=1, p=2, w=11)

arboretum.stand.m2 <- savitzkyGolay(arboretum.stand, m=2, p=2, w=11)

#Derivatives

#derivative 1 PCA
#PCA
arboretum.pca <- prcomp(arboretum.stand.m1)


#Importance of PCA axes
summary(arboretum.pca)

par(mar = c(4,4,2,1)+0.1)
barplot(summary(arboretum.pca)[[6]][3,1:10],
        ylim = c(0, 1), las = 1, xlab = "PC axes",
        ylab = "Cumulative proportion of variance",
        main = "")
abline(h = 0.9, lty = 2)

#Plot up
arboretum.pca.scores <- as.data.frame(arboretum.pca$x)

plot(arboretum.pca.scores[,1],
     arboretum.pca.scores[,2],
     type = "p", xlab = "", ylab = "",
     las=1, pch = 16,
     col = "red",
     main = "", yaxt = "n", xaxt = "n")

axis(1, lwd = 0, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1)
axis(2, lwd = 0, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1)
title(xlab = "PCA 1", line = 2)
title(ylab = "PCA 2", line = 2)

# text(arboretum.pca.scores[,1],
# arboretum.pca.scores[,2], labels = rownames(arboretum.pca.scores), 
# cex = 0.5, pos = 1)


# derivative 1 PCA PC1 vs PC2, colours, labels outside plot
par(mar = c(6, 5, 4, 8))

plot(arboretum.pca.scores[,1],
     arboretum.pca.scores[,2],
     type = "n", xlab = "PC1", ylab = "PC2 ",
     las=1, 
     main = "")

points(arboretum.pca.scores[arboretum.info$Taxon=="Bid",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Bid",2],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cun",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Cun",2],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cor",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Cor",2],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Lan",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Lan",2],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mac",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Mac",2],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mont",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Mont",2],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Moor",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Moor",2],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Ova",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Ova",2],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)


legend("topright",
       inset = c(-0.48, 0),
       legend = c("Ar. bidwilli", "Ar. cunninghamii",
                  "Ag. corbassonii",  "Ag. lanceolata",
                  "Ag. macrophylla", "Ag. montana",
                  "Ag. moorei", "Ag. ovata"),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21),
       col = c(plotting.cols[1:2], rep("black", 6)),
       pt.bg = c(NA, NA, plotting.cols[3:8]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)

#same as above but with shortened legend
par(mar = c(6, 5, 4, 8))

plot(arboretum.pca.scores[,1],
     arboretum.pca.scores[,2],
     type = "n", xlab = "PC1", ylab = "PC2 ",
     las=1, 
     main = "")

points(arboretum.pca.scores[arboretum.info$Taxon=="Bid",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Bid",2],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cun",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Cun",2],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cor",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Cor",2],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Lan",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Lan",2],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mac",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Mac",2],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mont",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Mont",2],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Moor",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Moor",2],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Ova",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Ova",2],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)


legend("topright",
       inset = c(-0.31, 0),
       legend = c("Ar. bidw.", "Ar. cunn.",
                  "Ag. corb.",  "Ag. lanc.",
                  "Ag. macr.", "Ag. mont.",
                  "Ag. moor", "Ag. ovat."),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21),
       col = c(plotting.cols[1:2], rep("black", 6)),
       pt.bg = c(NA, NA, plotting.cols[3:8]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)

# text(arboretum.pca.scores[,1],
# arboretum.pca.scores[,3], labels = rownames(arboretum.pca.scores), 
# cex = 0.5, pos = 1)


# derivative 1 PCA PC1 vs PC3, colours, labels outside plot
par(mar = c(6, 5, 4, 8))

plot(arboretum.pca.scores[,1],
     arboretum.pca.scores[,3],
     type = "n", xlab = "PC1", ylab = "PC3",
     las=1, 
     main = "")

points(arboretum.pca.scores[arboretum.info$Taxon=="Bid",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Bid",3],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cun",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Cun",3],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cor",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Cor",3],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Lan",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Lan",3],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mac",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Mac",3],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mont",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Mont",3],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Moor",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Moor",3],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Ova",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Ova",3],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)


legend("topright",
       inset = c(-0.55, 0),
       legend = c("Ar. bidwilli", "Ar. cunninghamii",
                  "Ag. corbassonii",  "Ag. lanceolata",
                  "Ag. macrophylla", "Ag. montana",
                  "Ag. moorei", "Ag. ovata"),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21),
       col = c(plotting.cols[1:2], rep("black", 6)),
       pt.bg = c(NA, NA, plotting.cols[3:8]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)


# text(arboretum.pca.scores[,2],
# arboretum.pca.scores[,3], labels = rownames(arboretum.pca.scores), 
# cex = 0.5, pos = 1)

# derivative 1 PCA PC2 vs PC3, colours, labels outside plot
par(mar = c(6, 5, 4, 8))
plot(arboretum.pca.scores[,2],
     arboretum.pca.scores[,3],
     type = "n", xlab = "PC2", ylab = "PC3",
     las=1, 
     main = "")

points(arboretum.pca.scores[arboretum.info$Taxon=="Bid",2],
       arboretum.pca.scores[arboretum.info$Taxon=="Bid",3],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cun",2],
       arboretum.pca.scores[arboretum.info$Taxon=="Cun",3],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cor",2],
       arboretum.pca.scores[arboretum.info$Taxon=="Cor",3],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Lan",2],
       arboretum.pca.scores[arboretum.info$Taxon=="Lan",3],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mac",2],
       arboretum.pca.scores[arboretum.info$Taxon=="Mac",3],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mont",2],
       arboretum.pca.scores[arboretum.info$Taxon=="Mont",3],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Moor",2],
       arboretum.pca.scores[arboretum.info$Taxon=="Moor",3],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Ova",2],
       arboretum.pca.scores[arboretum.info$Taxon=="Ova",3],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)


legend("topright",
       inset = c(-0.55, 0),
       legend = c("Ar. bidwilli", "Ar. cunninghamii",
                  "Ag. corbassonii",  "Ag. lanceolata",
                  "Ag. macrophylla", "Ag. montana",
                  "Ag. moorei", "Ag. ovata"),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21),
       col = c(plotting.cols[1:2], rep("black", 6)),
       pt.bg = c(NA, NA, plotting.cols[3:8]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)

# text(arboretum.pca.scores[,1],
# arboretum.pca.scores[,4], labels = rownames(arboretum.pca.scores), 
# cex = 0.5, pos = 1)

# derivative 1 PCA PC1 vs PC4, colours, labels outside plot
par(mar = c(6, 5, 4, 8))

plot(arboretum.pca.scores[,1],
     arboretum.pca.scores[,4],
     type = "n", xlab = "PC1", ylab = "PC4",
     las=1, 
     main = "")

points(arboretum.pca.scores[arboretum.info$Taxon=="Bid",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Bid",4],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cun",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Cun",4],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cor",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Cor",4],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Lan",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Lan",4],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mac",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Mac",4],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mont",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Mont",4],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Moor",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Moor",4],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Ova",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Ova",4],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)

legend("topright",
       inset = c(-0.55, 0),
       legend = c("Ar. bidwilli", "Ar. cunninghamii",
                  "Ag. corbassonii",  "Ag. lanceolata",
                  "Ag. macrophylla", "Ag. montana",
                  "Ag. moorei", "Ag. ovata"),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21),
       col = c(plotting.cols[1:2], rep("black", 6)),
       pt.bg = c(NA, NA, plotting.cols[3:8]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)

#second derivative
#PCA
arboretum.pca <- prcomp(arboretum.stand.m2)
#Importance of PCA axes
summary(arboretum.pca)

par(mar = c(4,4,2,1)+0.1)
barplot(summary(arboretum.pca)[[6]][3,1:10],
        ylim = c(0, 1), las = 1, xlab = "PC axes",
        ylab = "Cumulative proportion of variance",
        main = "")
abline(h = 0.9, lty = 2)

#Plot up
arboretum.pca.scores <- as.data.frame(arboretum.pca$x)

plot(arboretum.pca.scores[,1],
     arboretum.pca.scores[,2],
     type = "p", xlab = "", ylab = "",
     las=1, pch = 16,
     col = "red",
     main = "", yaxt = "n", xaxt = "n")

axis(1, lwd = 0, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1)
axis(2, lwd = 0, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1)
title(xlab = "PCA 1", line = 2)
title(ylab = "PCA 2", line = 2)

#text(arboretum.pca.scores[,1],
# arboretum.pca.scores[,2], labels = rownames(arboretum.pca.scores), 
# cex = 0.5, pos = 1)

#derivative 2 PCA PC1 vs PC2, colours, label outside plot
par(mar = c(6, 5, 4, 8))

plot(arboretum.pca.scores[,1],
     arboretum.pca.scores[,2],
     type = "n", xlab = "PC1", ylab = "PC2",
     las=1, 
     main = "")

points(arboretum.pca.scores[arboretum.info$Taxon=="Bid",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Bid",2],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cun",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Cun",2],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cor",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Cor",2],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Lan",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Lan",2],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mac",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Mac",2],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mont",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Mont",2],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Moor",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Moor",2],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Ova",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Ova",2],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)


legend("topright",
       inset = c(-0.55, 0),
       legend = c("Ar. bidwilli", "Ar. cunninghamii",
                  "Ag. corbassonii",  "Ag. lanceolata",
                  "Ag. macrophylla", "Ag. montana",
                  "Ag. moorei", "Ag. ovata"),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21),
       col = c(plotting.cols[1:2], rep("black", 6)),
       pt.bg = c(NA, NA, plotting.cols[3:8]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)

#same as above but with shortened names in legend
par(mar = c(6, 5, 4, 8))

plot(arboretum.pca.scores[,1],
     arboretum.pca.scores[,2],
     type = "n", xlab = "PC1", ylab = "PC2",
     las=1, 
     main = "")

points(arboretum.pca.scores[arboretum.info$Taxon=="Bid",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Bid",2],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cun",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Cun",2],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cor",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Cor",2],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Lan",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Lan",2],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mac",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Mac",2],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mont",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Mont",2],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Moor",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Moor",2],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Ova",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Ova",2],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)
legend("topright",
       inset = c(-0.31, 0),
       legend = c("Ar. bidw.", "Ar. cunn.",
                  "Ag. corb.",  "Ag. lanc.",
                  "Ag. macr.", "Ag. mont.",
                  "Ag. moor", "Ag. ovat."),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21),
       col = c(plotting.cols[1:2], rep("black", 6)),
       pt.bg = c(NA, NA, plotting.cols[3:8]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)

#derivative 2 PCA PC1 vs PC3, colours, label outside plot
par(mar = c(6, 5, 4, 8))

plot(arboretum.pca.scores[,1],
     arboretum.pca.scores[,3],
     type = "n", xlab = "PC1", ylab = "PC3",
     las=1, 
     main = "")

points(arboretum.pca.scores[arboretum.info$Taxon=="Bid",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Bid",3],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cun",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Cun",3],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cor",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Cor",3],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Lan",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Lan",3],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mac",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Mac",3],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mont",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Mont",3],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Moor",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Moor",3],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Ova",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Ova",3],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)


legend("topright",
       inset = c(-0.55, 0),
       legend = c("Ar. bidwilli", "Ar. cunninghamii",
                  "Ag. corbassonii",  "Ag. lanceolata",
                  "Ag. macrophylla", "Ag. montana",
                  "Ag. moorei", "Ag. ovata"),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21),
       col = c(plotting.cols[1:2], rep("black", 6)),
       pt.bg = c(NA, NA, plotting.cols[3:8]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)


#derivative 2 PCA PC2 vs PC3, colours, label outside plot
par(mar = c(6, 5, 4, 8))

plot(arboretum.pca.scores[,2],
     arboretum.pca.scores[,3],
     type = "n", xlab = "PC2", ylab = "PC3",
     las=1, 
     main = "")

points(arboretum.pca.scores[arboretum.info$Taxon=="Bid",2],
       arboretum.pca.scores[arboretum.info$Taxon=="Bid",3],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cun",2],
       arboretum.pca.scores[arboretum.info$Taxon=="Cun",3],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cor",2],
       arboretum.pca.scores[arboretum.info$Taxon=="Cor",3],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Lan",2],
       arboretum.pca.scores[arboretum.info$Taxon=="Lan",3],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mac",2],
       arboretum.pca.scores[arboretum.info$Taxon=="Mac",3],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mont",2],
       arboretum.pca.scores[arboretum.info$Taxon=="Mont",3],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Moor",2],
       arboretum.pca.scores[arboretum.info$Taxon=="Moor",3],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Ova",2],
       arboretum.pca.scores[arboretum.info$Taxon=="Ova",3],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)


legend("topright",
       inset = c(-0.55, 0),
       legend = c("Ar. bidwilli", "Ar. cunninghamii",
                  "Ag. corbassonii",  "Ag. lanceolata",
                  "Ag. macrophylla", "Ag. montana",
                  "Ag. moorei", "Ag. ovata"),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21),
       col = c(plotting.cols[1:2], rep("black", 6)),
       pt.bg = c(NA, NA, plotting.cols[3:8]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)


#derivative 2 PCA PC1 vs PC4, colours, label outside plot
par(mar = c(6, 5, 4, 8))

plot(arboretum.pca.scores[,1],
     arboretum.pca.scores[,4],
     type = "n", xlab = "PC1", ylab = "PC4",
     las=1, 
     main = "")

points(arboretum.pca.scores[arboretum.info$Taxon=="Bid",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Bid",4],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cun",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Cun",4],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Cor",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Cor",4],
       pch=21, col = "black", bg = plotting.cols[3],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Lan",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Lan",4],
       pch=22, col = "black", bg = plotting.cols[4],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mac",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Mac",4],
       pch=22, col = "black", bg = plotting.cols[5],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Mont",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Mont",4],
       pch=24, col = "black", bg = plotting.cols[6],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Moor",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Moor",4],
       pch=25, col = "black", bg = plotting.cols[7],
       cex = 1.2)

points(arboretum.pca.scores[arboretum.info$Taxon=="Ova",1],
       arboretum.pca.scores[arboretum.info$Taxon=="Ova",4],
       pch=21, col = "black", bg = plotting.cols[8],
       cex = 1.2)


legend("topright",
       inset = c(-0.55, 0),
       legend = c("Ar. bidwilli", "Ar. cunninghamii",
                  "Ag. corbassonii",  "Ag. lanceolata",
                  "Ag. macrophylla", "Ag. montana",
                  "Ag. moorei", "Ag. ovata"),
       bty = "n",
       pch = c(15, 17, 21, 22, 22, 24, 25, 21),
       col = c(plotting.cols[1:2], rep("black", 6)),
       pt.bg = c(NA, NA, plotting.cols[3:8]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)


#derivative 1 PCA loadings

wavenumbers.sg <- as.numeric(sub("X", "", colnames(arboretum.stand.m1)))

arboretum.pca.loadings <- as.data.frame(arboretum.pca$rotation)

plot(wavenumbers.sg,
     arboretum.pca.loadings[,1],
     type = "l", xlab = "wavenumbers", ylab = "PC1 loadings",
     las=1,
     main = "", xlim = c(4000, 500))


plot(wavenumbers.sg,
     arboretum.pca.loadings[,2],
     type = "l", xlab = "wavenumbers", ylab = "PC1 loadings",
     las=1,
     main = "", xlim = c(4000, 500))


plot(wavenumbers.sg,
     arboretum.pca.loadings[,3],
     type = "l", xlab = "wavenumbers", ylab = "PC1 loadings",
     las=1,
     main = "", xlim = c(4000, 500))


#derivative 2 PCA loadings

wavenumbers.sg <- as.numeric(sub("X", "", colnames(arboretum.stand.m1)))

arboretum.pca.loadings <- as.data.frame(arboretum.pca$rotation)
plot(wavenumbers.sg,
     arboretum.pca.loadings[,1],
     type = "l", xlab = "wavenumbers", ylab = "PC1 loadings",
     las=1,
     main = "", xlim = c(4000, 500))

plot(wavenumbers.sg,
     arboretum.pca.loadings[,2],
     type = "l", xlab = "wavenumbers", ylab = "PC1 loadings",
     las=1,
     main = "", xlim = c(4000, 500))

plot(wavenumbers.sg,
     arboretum.pca.loadings[,3],
     type = "l", xlab = "wavenumbers", ylab = "PC1 loadings",
     las=1,
     main = "", xlim = c(4000, 500))


#first derivative
#Cluster analysis
arboretum.clust <- hclust(dist(arboretum.stand.m1), method = "average")
plot(arboretum.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

plot(arboretum.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = arboretum.info$Taxon)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

plot(arboretum.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = arboretum.info$Genus)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

#second derivative
#Cluster analysis
arboretum.clust <- hclust(dist(arboretum.stand.m2), method = "average")
plot(arboretum.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

plot(arboretum.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = arboretum.info$Taxon)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

plot(arboretum.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = arboretum.info$Genus)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

#Taxon mean cluster analysis
#first derivative
arboretum.stand.m1.means <- aggregate(arboretum.stand.m1, by = list(arboretum.info$Taxon),
                                      FUN = mean)
rownames(arboretum.stand.m1.means) <- arboretum.stand.m1.means[,1]
arboretum.stand.m1.means <- arboretum.stand.m1.means[,-1]

arboretum.stand.m1.means.clust <- hclust(dist(arboretum.stand.m1.means), method = "average")
plot(arboretum.stand.m1.means.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)


#Taxon mean cluster analysis
#second derivative
arboretum.stand.m2.means <- aggregate(arboretum.stand.m2, by = list(arboretum.info$Taxon),
                                      FUN = mean)
rownames(arboretum.stand.m2.means) <- arboretum.stand.m2.means[,1]
arboretum.stand.m2.means <- arboretum.stand.m2.means[,-1]

arboretum.stand.m2.means.clust <- hclust(dist(arboretum.stand.m2.means), method = "average")
plot(arboretum.stand.m2.means.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

