#Load packages
library(baseline)
library(prospectr)
library(RColorBrewer)


#Read in data tables (NB set the working directory to where you have the files first!)
wild <- read.table("wild.txt", header = T, row.names = 1)
wild.info <- read.table("wild meta.txt", header = T, row.names = 1)

wavenumbers <- as.numeric(unlist(strsplit(colnames(wild), "X"))[seq(2, 2*1764, by = 2)])



#Z-score standardisation
wild.stand <- t(scale(t(wild)))

#PCA
#Unprocessed spectra
wild.pca <- prcomp(wild.stand)
#Importance of PCA axes
summary(wild.pca)

par(mar = c(4,4,2,1)+0.1)
barplot(summary(wild.pca)[[6]][3,1:10],
        ylim = c(0, 1), las = 1, xlab = "PC axes",
        ylab = "Cumulative proportion of variance",
        main = "")
abline(h = 0.9, lty = 2)

#Plot up
wild.pca.scores <- as.data.frame(wild.pca$x)

plot(wild.pca.scores[,1],
     wild.pca.scores[,2],
     type = "p", xlab = "", ylab = "",
     las=1, pch = 16,
     col = "red",
     main = "", yaxt = "n", xaxt = "n")

axis(1, lwd = 0, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1)
axis(2, lwd = 0, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1)
title(xlab = "PCA 1 (50.07%)", line = 2)
title(ylab = "PCA 2 (18.84%)", line = 2)

#     text(wild.pca.scores[,1],
#     wild.pca.scores[,2], labels = rownames(wild.pca.scores), 
#     cex = 0.5, pos = 1)

plot(wild.pca.scores[,1],
     wild.pca.scores[,2],
     type = "n", xlab = "PC1 (50.07%)", ylab = "PC2 (18.84%)",
     las=1, 
     main = "")

points(wild.pca.scores[wild.info$Taxon=="Col_W",1],
       wild.pca.scores[wild.info$Taxon=="Col_W",2],
       pch=1, col = "red")

points(wild.pca.scores[wild.info$Taxon=="Lan_W",1],
       wild.pca.scores[wild.info$Taxon=="Lan_W",2],
       pch=15, col = "darkgreen")

points(wild.pca.scores[wild.info$Taxon=="Nem_W",1],
       wild.pca.scores[wild.info$Taxon=="Nem_W",2],
       pch=15, col = "orange")

points(wild.pca.scores[wild.info$Taxon=="Ova_W",1],
       wild.pca.scores[wild.info$Taxon=="Ova_W",2],
       pch=15, col = "black")

legend("topright", legend = c("Col_W", "Lan_W", "Nem_W", "Ova_W"),
       pch = c(1, 15, 15, 15), col = c("red", "darkgreen", "orange", "black"), y.intersp=0.8)



#   text(wild.pca.scores[,1],
#   wild.pca.scores[,3], labels = rownames(wild.pca.scores), 
#  cex = 0.5, pos = 1)

plot(wild.pca.scores[,1],
     wild.pca.scores[,3],
     type = "n", xlab = "PC1 (50.07%)", ylab = "PC3 (15.54%)",
     las=1, 
     main = "")


points(wild.pca.scores[wild.info$Taxon=="Col_W",1],
       wild.pca.scores[wild.info$Taxon=="Col_W",3],
       pch=1, col = "red")

points(wild.pca.scores[wild.info$Taxon=="Lan_W",1],
       wild.pca.scores[wild.info$Taxon=="Lan_W",3],
       pch=15, col = "darkgreen")

points(wild.pca.scores[wild.info$Taxon=="Nem_W",1],
       wild.pca.scores[wild.info$Taxon=="Nem_W",3],
       pch=15, col = "orange")

points(wild.pca.scores[wild.info$Taxon=="Ova_W",1],
       wild.pca.scores[wild.info$Taxon=="Ova_W",3],
       pch=15, col = "black")

legend("bottomleft", legend = c("Col_W", "Lan_W", "Nem_W", "Ova_W"),
       pch = c(1, 15, 15, 15), col = c("red", "darkgreen", "orange", "black"), y.intersp=0.8)




plot(wild.pca.scores[,2],
     wild.pca.scores[,3],
     type = "n", xlab = "PC2 (18.84%)", ylab = "PC3 (15.54%)",
     las=1, 
     main = "")

points(wild.pca.scores[wild.info$Taxon=="Col_W",2],
       wild.pca.scores[wild.info$Taxon=="Col_W",3],
       pch=1, col = "red")

points(wild.pca.scores[wild.info$Taxon=="Lan_W",2],
       wild.pca.scores[wild.info$Taxon=="Lan_W",3],
       pch=15, col = "darkgreen")

points(wild.pca.scores[wild.info$Taxon=="Nem_W",2],
       wild.pca.scores[wild.info$Taxon=="Nem_W",3],
       pch=15, col = "orange")

points(wild.pca.scores[wild.info$Taxon=="Ova_W",2],
       wild.pca.scores[wild.info$Taxon=="Ova_W",3],
       pch=15, col = "black")

legend("topright", legend = c("Col_W", "Lan_W", "Nem_W", "Ova_W"),
       pch = c(1, 15, 15, 15), col = c("red", "darkgreen", "orange", "black"), y.intersp=0.8)



plot(wild.pca.scores[,1],
     wild.pca.scores[,4],
     type = "n", xlab = "PC1 (50.07%)", ylab = "PC4 (8.27%)",
     las=1, 
     main = "")

points(wild.pca.scores[wild.info$Taxon=="Col_W",1],
       wild.pca.scores[wild.info$Taxon=="Col_W",4],
       pch=1, col = "red")

points(wild.pca.scores[wild.info$Taxon=="Lan_W",1],
       wild.pca.scores[wild.info$Taxon=="Lan_W",4],
       pch=15, col = "darkgreen")

points(wild.pca.scores[wild.info$Taxon=="Nem_W",1],
       wild.pca.scores[wild.info$Taxon=="Nem_W",4],
       pch=15, col = "orange")

points(wild.pca.scores[wild.info$Taxon=="Ova_W",1],
       wild.pca.scores[wild.info$Taxon=="Ova_W",4],
       pch=15, col = "black")

legend("bottomleft", legend = c("Col_W", "Lan_W", "Nem_W", "Ova_W"),
       pch = c(1, 15, 15, 15), col = c("red", "darkgreen", "orange", "black"), y.intersp=0.8)



wild.pca.loadings <- as.data.frame(wild.pca$rotation)
plot(wavenumbers,
     wild.pca.loadings[,1],
     type = "l", xlab = "wavenumbers", ylab = "PC1 loadings",
     las=1,
     main = "", xlim = c(4000, 500))
##This plot shows some baseline drift towards the lower wavenumbers
#so baseline correction is necessary

plot(wavenumbers,
     wild.pca.loadings[,2],
     type = "l", xlab = "wavenumbers", ylab = "PC2 loadings",
     las=1,
     main = "", xlim = c(4000, 500))

plot(wavenumbers,
     wild.pca.loadings[,3],
     type = "l", xlab = "wavenumbers", ylab = "PC3 loadings",
     las=1,
     main = "", xlim = c(4000, 500))

plot(wavenumbers,
     wild.pca.loadings[,4],
     type = "l", xlab = "wavenumbers", ylab = "PC4 loadings",
     las=1,
     main = "", xlim = c(4000, 500))


#Cluster analysis
wild.clust <- hclust(dist(wild.stand), method = "average")
plot(wild.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

#by taxon
plot(wild.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = wild.info$Taxon)
axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

#by genus
plot(wild.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = wild.info$Genus)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)



#Taxon mean cluster analysis
wild.stand.means <- aggregate(wild.stand, by = list(wild.info$Taxon),
                                   FUN = mean)
rownames(wild.stand.means) <- wild.stand.means[,1]
wild.stand.means <- wild.stand.means[,-1]

wild.stand.means.clust <- hclust(dist(wild.stand.means), method = "average")
plot(wild.stand.means.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

#####
#baseline corrected
#Repeat with baseline correction
#Load packages
library(baseline)

wild.base <- baseline(as.matrix(wild),
                           method='modpolyfit', deg=2)
wild.cor <- getCorrected(wild.base)
colnames(wild.cor) <- wavenumbers
wild.cor <- as.data.frame(wild.cor,
                               row.names = rownames(wild))

wild.cor.stand <- t(scale(t(wild.cor)))

#PCA
#Baseline corrected spectra
wild.cor.pca <- prcomp(wild.cor.stand)
#Importance of PCA axes
summary(wild.cor.pca)

par(mar = c(4,4,2,1)+0.1)
barplot(summary(wild.cor.pca)[[6]][3,1:10],
        ylim = c(0, 1), las = 1, xlab = "PC axes",
        ylab = "Cumulative proportion of variance",
        main = "")
abline(h = 0.9, lty = 2)


##########################
#points labeled on baseline corrected data
#Plot up
wild.pca.scores <- as.data.frame(wild.pca$x)

plot(wild.cor.pca.scores[,1],
     wild.cor.pca.scores[,2],
     type = "p", xlab = "", ylab = "",
     las=1, pch = 16,
     col = "red",
     main = "", yaxt = "n", xaxt = "n")

axis(1, lwd = 0, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1)
axis(2, lwd = 0, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1)
title(xlab = "PCA 1 ", line = 2)
title(ylab = "PCA 2 ", line = 2)

    text(wild.cor.pca.scores[,1],
    wild.cor.pca.scores[,2], labels = rownames(wild.cor.pca.scores), 
    cex = 0.5, pos = 1)


##########################

##colours corrected for following baseline corrected plots
#Plot up
wild.cor.pca.scores <- as.data.frame(wild.cor.pca$x)

#install.packages("RColorBrewer")
library("RColorBrewer")
display.brewer.all() #displays all palettes
display.brewer.all(type = "qual", colorblindFriendly = TRUE)

#To select colours for plotting use:
plotting.cols <- brewer.pal(n = 8, name = "Paired")

par(mar = c(6, 5, 4, 8))
plot(wild.cor.pca.scores[,1],
     wild.cor.pca.scores[,2],
     type = "n", xlab = "PC1 (54.05%)", ylab = "PC2 (19.87%) ",
     las=1, 
     main = "")

points(wild.cor.pca.scores[wild.info$Taxon=="Lan_W",1],
       wild.cor.pca.scores[wild.info$Taxon=="Lan_W",2],
       pch=22, col = "darkgreen", bg = plotting.cols[3],
       cex = 1.2)

points(wild.cor.pca.scores[wild.info$Taxon=="Ova_W",1],
       wild.cor.pca.scores[wild.info$Taxon=="Ova_W",2],
       pch=21, col = "brown", bg = plotting.cols[7],
       cex = 1.2)

points(wild.cor.pca.scores[wild.info$Taxon=="Col_W",1],
       wild.cor.pca.scores[wild.info$Taxon=="Col_W",2],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(wild.cor.pca.scores[wild.info$Taxon=="Nem_W",1],
       wild.cor.pca.scores[wild.info$Taxon=="Nem_W",2],
       pch=17, col = plotting.cols[2],
       cex = 1.2)




legend("topright",
       inset = c(-0.38, 0),
       legend = c("Ag. lanc.", "Ag. ovat.", "Ar. col.",
                  "Ar. nem." ),
       bty = "n",
       pch = c(22, 21, 15, 17),
       col = c("darkgreen", "brown", plotting.cols[1], plotting.cols[2]),
       pt.bg = c(plotting.cols[3], plotting.cols[7], NA, NA),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)



par(mar = c(6, 5, 4, 8))
plot(wild.cor.pca.scores[,1],
     wild.cor.pca.scores[,3],
     type = "n", xlab = "PC1 (54.05%)", ylab = "PC3 (9.7%) ",
     las=1, 
     main = "")

points(wild.cor.pca.scores[wild.info$Taxon=="Col_W",1],
       wild.cor.pca.scores[wild.info$Taxon=="Col_W",3],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(wild.cor.pca.scores[wild.info$Taxon=="Lan_W",1],
       wild.cor.pca.scores[wild.info$Taxon=="Lan_W",3],
       pch=22, col = "darkgreen", bg = plotting.cols[3],
       cex = 1.2)

points(wild.cor.pca.scores[wild.info$Taxon=="Nem_W",1],
       wild.cor.pca.scores[wild.info$Taxon=="Nem_W",3],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(wild.cor.pca.scores[wild.info$Taxon=="Ova_W",1],
       wild.cor.pca.scores[wild.info$Taxon=="Ova_W",3],
       pch=21, col = "brown", bg = plotting.cols[7],
       cex = 1.2)


legend("topright",
       inset = c(-0.35, 0),
       legend = c("Ar. col.", "Ag. lanc.",
                  "Ar. nem.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 22, 17, 21),
       col = c(plotting.cols[1], "darkgreen", plotting.cols[2], "brown"),
       pt.bg = c(NA, plotting.cols[3], NA, plotting.cols[7]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)


par(mar = c(6, 5, 4, 8))
plot(wild.cor.pca.scores[,2],
     wild.cor.pca.scores[,3],
     type = "n", xlab = "PC2 (19.87%)", ylab = "PC3 (9.7%) ",
     las=1, 
     main = "")

points(wild.cor.pca.scores[wild.info$Taxon=="Col_W",2],
       wild.cor.pca.scores[wild.info$Taxon=="Col_W",3],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(wild.cor.pca.scores[wild.info$Taxon=="Lan_W",2],
       wild.cor.pca.scores[wild.info$Taxon=="Lan_W",3],
       pch=22, col = "darkgreen", bg = plotting.cols[3],
       cex = 1.2)

points(wild.cor.pca.scores[wild.info$Taxon=="Nem_W",2],
       wild.cor.pca.scores[wild.info$Taxon=="Nem_W",3],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(wild.cor.pca.scores[wild.info$Taxon=="Ova_W",2],
       wild.cor.pca.scores[wild.info$Taxon=="Ova_W",3],
       pch=21, col = "brown", bg = plotting.cols[7],
       cex = 1.2)


legend("topright",
       inset = c(-0.35, 0),
       legend = c("Ar. col.", "Ag. lanc.",
                  "Ar. nem.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 22, 17, 21),
       col = c(plotting.cols[1], "darkgreen", plotting.cols[2], "brown"),
       pt.bg = c(NA, plotting.cols[3], NA, plotting.cols[7]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)


par(mar = c(6, 5, 4, 8))
plot(wild.cor.pca.scores[,1],
     wild.cor.pca.scores[,4],
     type = "n", xlab = "PC1 (54.05%)", ylab = "PC4 (7.8%) ",
     las=1, 
     main = "")

points(wild.cor.pca.scores[wild.info$Taxon=="Col_W",1],
       wild.cor.pca.scores[wild.info$Taxon=="Col_W",4],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(wild.cor.pca.scores[wild.info$Taxon=="Lan_W",1],
       wild.cor.pca.scores[wild.info$Taxon=="Lan_W",4],
       pch=22, col = "darkgreen", bg = plotting.cols[3],
       cex = 1.2)

points(wild.cor.pca.scores[wild.info$Taxon=="Nem_W",1],
       wild.cor.pca.scores[wild.info$Taxon=="Nem_W",4],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(wild.cor.pca.scores[wild.info$Taxon=="Ova_W",1],
       wild.cor.pca.scores[wild.info$Taxon=="Ova_W",4],
       pch=21, col = "brown", bg = plotting.cols[7],
       cex = 1.2)


legend("topright",
       inset = c(-0.35, 0),
       legend = c("Ar. col.", "Ag. lanc.",
                  "Ar. nem.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 22, 17, 21),
       col = c(plotting.cols[1], "darkgreen", plotting.cols[2], "brown"),
       pt.bg = c(NA, plotting.cols[3], NA, plotting.cols[7]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)



#Loadings

par(mar = c(4,4,2,1)+0.1)

wild.cor.pca.loadings <- as.data.frame(wild.cor.pca$rotation)
plot(wavenumbers, wild.cor.pca.loadings[,1],
     type = "l", xlab = expression(paste("Wavenumbers cm"^"-1")), ylab = "PC1 loadings",
     las=1, main = "", xlim = c(4000, 500))

plot(wavenumbers, wild.cor.pca.loadings[,2],
     type = "l", xlab = expression(paste("Wavenumbers cm"^"-1")), ylab = "PC2 loadings",
     las=1, main = "", xlim = c(4000, 500))

plot(wavenumbers, wild.cor.pca.loadings[,3],
     type = "l", xlab = expression(paste("Wavenumbers cm"^"-1")), ylab = "PC3 loadings",
     las=1, main = "", xlim = c(4000, 500))

plot(wavenumbers, wild.cor.pca.loadings[,4],
     type = "l", xlab = expression(paste("Wavenumbers cm"^"-1")), ylab = "PC4 loadings",
     las=1, main = "", xlim = c(4000, 500))

#Cluster analysis
wild.cor.clust <- hclust(dist(wild.cor.stand), method = "average")
plot(wild.cor.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

plot(wild.cor.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = wild.info$Taxon)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

plot(wild.cor.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = wild.info$Genus)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

#plot corrected mean taxon spectra
wild.cor.stand.means <- aggregate(wild.cor.stand, by = list(wild.info$Taxon),
                                       FUN = mean)
rownames(wild.cor.stand.means) <- wild.cor.stand.means[,1]
wild.cor.stand.means <- wild.cor.stand.means[,-1]

wild.cor.stand.means.clust <- hclust(dist(wild.stand.means), method = "average")
plot(wild.cor.stand.means.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

#derivatives of spectra

#Z-score standardisation for derivatives
wild.stand.m1 <- savitzkyGolay(wild.stand, m=1, p=2, w=11)

wild.stand.m2 <- savitzkyGolay(wild.stand, m=2, p=2, w=11)


#derivative 1 PCA
#PCA
wild.pca <- prcomp(wild.stand.m1)
#Importance of PCA axes
summary(wild.pca)

par(mar = c(4,4,2,1)+0.1)
barplot(summary(wild.pca)[[6]][3,1:10],
        ylim = c(0, 1), las = 1, xlab = "PC axes",
        ylab = "Cumulative proportion of variance",
        main = "")
abline(h = 0.9, lty = 2)

#Plot up
wild.pca.scores <- as.data.frame(wild.pca$x)

plot(wild.pca.scores[,1],
     wild.pca.scores[,2],
     type = "p", xlab = "", ylab = "",
     las=1, pch = 16,
     col = "red",
     main = "", yaxt = "n", xaxt = "n")

axis(1, lwd = 0, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1)
axis(2, lwd = 0, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1)
title(xlab = "PCA 1", line = 2)
title(ylab = "PCA 2", line = 2)

# text(wild.pca.scores[,1],
# wild.pca.scores[,2], labels = rownames(wild.pca.scores), 
# cex = 0.5, pos = 1)


par(mar = c(6, 5, 4, 8))
plot(wild.pca.scores[,1],
     wild.pca.scores[,2],
     type = "n", xlab = "PC1", ylab = "PC2",
     las=1, 
     main = "")

points(wild.pca.scores[wild.info$Taxon=="Col_W",1],
       wild.pca.scores[wild.info$Taxon=="Col_W",2],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(wild.pca.scores[wild.info$Taxon=="Lan_W",1],
       wild.pca.scores[wild.info$Taxon=="Lan_W",2],
       pch=22, col = "darkgreen", bg = plotting.cols[3],
       cex = 1.2)

points(wild.pca.scores[wild.info$Taxon=="Nem_W",1],
       wild.pca.scores[wild.info$Taxon=="Nem_W",2],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(wild.pca.scores[wild.info$Taxon=="Ova_W",1],
       wild.pca.scores[wild.info$Taxon=="Ova_W",2],
       pch=21, col = "brown", bg = plotting.cols[7],
       cex = 1.2)


legend("topright",
       inset = c(-0.38, 0),
       legend = c("Ar. col.", "Ag. lanc.",
                  "Ar. nem.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 22, 17, 21),
       col = c(plotting.cols[1], "darkgreen", plotting.cols[2], "brown"),
       pt.bg = c(NA, plotting.cols[3], NA, plotting.cols[7]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)

# text(wild.pca.scores[,1],
# wild.pca.scores[,3], labels = rownames(wild.pca.scores), 
# cex = 0.5, pos = 1)

par(mar = c(6, 5, 4, 8))
plot(wild.pca.scores[,1],
     wild.pca.scores[,3],
     type = "n", xlab = "PC1", ylab = "PC3",
     las=1, 
     main = "")

points(wild.pca.scores[wild.info$Taxon=="Col_W",1],
       wild.pca.scores[wild.info$Taxon=="Col_W",3],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(wild.pca.scores[wild.info$Taxon=="Lan_W",1],
       wild.pca.scores[wild.info$Taxon=="Lan_W",3],
       pch=22, col = "darkgreen", bg = plotting.cols[3],
       cex = 1.2)

points(wild.pca.scores[wild.info$Taxon=="Nem_W",1],
       wild.pca.scores[wild.info$Taxon=="Nem_W",3],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(wild.pca.scores[wild.info$Taxon=="Ova_W",1],
       wild.pca.scores[wild.info$Taxon=="Ova_W",3],
       pch=21, col = "brown", bg = plotting.cols[7],
       cex = 1.2)


legend("topright",
       inset = c(-0.38, 0),
       legend = c("Ar. col.", "Ag. lanc.",
                  "Ar. nem.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 22, 17, 21),
       col = c(plotting.cols[1], "darkgreen", plotting.cols[2], "brown"),
       pt.bg = c(NA, plotting.cols[3], NA, plotting.cols[7]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)




# text(wild.pca.scores[,2],
# wild.pca.scores[,3], labels = rownames(wild.pca.scores), 
# cex = 0.5, pos = 1)

par(mar = c(6, 5, 4, 8))
plot(wild.pca.scores[,2],
     wild.pca.scores[,3],
     type = "n", xlab = "PC2", ylab = "PC3",
     las=1, 
     main = "")

points(wild.pca.scores[wild.info$Taxon=="Col_W",2],
       wild.pca.scores[wild.info$Taxon=="Col_W",3],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(wild.pca.scores[wild.info$Taxon=="Lan_W",2],
       wild.pca.scores[wild.info$Taxon=="Lan_W",2],
       pch=22, col = "darkgreen", bg = plotting.cols[3],
       cex = 1.2)

points(wild.pca.scores[wild.info$Taxon=="Nem_W",2],
       wild.pca.scores[wild.info$Taxon=="Nem_W",2],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(wild.pca.scores[wild.info$Taxon=="Ova_W",2],
       wild.pca.scores[wild.info$Taxon=="Ova_W",3],
       pch=21, col = "brown", bg = plotting.cols[7],
       cex = 1.2)


legend("topright",
       inset = c(-0.38, 0),
       legend = c("Ar. col.", "Ag. lanc.",
                  "Ar. nem.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 22, 17, 21),
       col = c(plotting.cols[1], "darkgreen", plotting.cols[2], "brown"),
       pt.bg = c(NA, plotting.cols[3], NA, plotting.cols[7]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)


# text(wild.pca.scores[,1],
# wild.pca.scores[,4], labels = rownames(wild.pca.scores), 
# cex = 0.5, pos = 1)

par(mar = c(6, 5, 4, 8))
plot(wild.pca.scores[,1],
     wild.pca.scores[,4],
     type = "n", xlab = "PC1", ylab = "PC4",
     las=1, 
     main = "")

points(wild.pca.scores[wild.info$Taxon=="Col_W",1],
       wild.pca.scores[wild.info$Taxon=="Col_W",4],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(wild.pca.scores[wild.info$Taxon=="Lan_W",1],
       wild.pca.scores[wild.info$Taxon=="Lan_W",4],
       pch=22, col = "darkgreen", bg = plotting.cols[3],
       cex = 1.2)

points(wild.pca.scores[wild.info$Taxon=="Nem_W",1],
       wild.pca.scores[wild.info$Taxon=="Nem_W",4],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(wild.pca.scores[wild.info$Taxon=="Ova_W",1],
       wild.pca.scores[wild.info$Taxon=="Ova_W",4],
       pch=21, col = "brown", bg = plotting.cols[7],
       cex = 1.2)


legend("topright",
       inset = c(-0.38, 0),
       legend = c("Ar. col.", "Ag. lanc.",
                  "Ar. nem.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 22, 17, 21),
       col = c(plotting.cols[1], "darkgreen", plotting.cols[2], "brown"),
       pt.bg = c(NA, plotting.cols[3], NA, plotting.cols[7]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)

#second derivative
#PCA
wild.pca <- prcomp(wild.stand.m2)
#Importance of PCA axes
summary(wild.pca)

par(mar = c(4,4,2,1)+0.1)
barplot(summary(wild.pca)[[6]][3,1:10],
        ylim = c(0, 1), las = 1, xlab = "PC axes",
        ylab = "Cumulative proportion of variance",
        main = "")
abline(h = 0.9, lty = 2)

#Plot up
wild.pca.scores <- as.data.frame(wild.pca$x)

plot(wild.pca.scores[,1],
     wild.pca.scores[,2],
     type = "p", xlab = "", ylab = "",
     las=1, pch = 16,
     col = "red",
     main = "", yaxt = "n", xaxt = "n")

axis(1, lwd = 0, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1)
axis(2, lwd = 0, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1)
title(xlab = "PCA 1", line = 2)
title(ylab = "PCA 2", line = 2)

#text(wild.pca.scores[,1],
# wild.pca.scores[,2], labels = rownames(wild.pca.scores), 
# cex = 0.5, pos = 1)


par(mar = c(6, 5, 4, 8))
plot(wild.pca.scores[,1],
     wild.pca.scores[,2],
     type = "n", xlab = "PC1", ylab = "PC2",
     las=1, 
     main = "")

points(wild.pca.scores[wild.info$Taxon=="Col_W",1],
       wild.pca.scores[wild.info$Taxon=="Col_W",2],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(wild.pca.scores[wild.info$Taxon=="Lan_W",1],
       wild.pca.scores[wild.info$Taxon=="Lan_W",2],
       pch=22, col = "darkgreen", bg = plotting.cols[3],
       cex = 1.2)

points(wild.pca.scores[wild.info$Taxon=="Nem_W",1],
       wild.pca.scores[wild.info$Taxon=="Nem_W",2],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(wild.pca.scores[wild.info$Taxon=="Ova_W",1],
       wild.pca.scores[wild.info$Taxon=="Ova_W",2],
       pch=21, col = "brown", bg = plotting.cols[7],
       cex = 1.2)


legend("topright",
       inset = c(-0.38, 0),
       legend = c("Ar. col.", "Ag. lanc.",
                  "Ar. nem.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 22, 17, 21),
       col = c(plotting.cols[1], "darkgreen", plotting.cols[2], "brown"),
       pt.bg = c(NA, plotting.cols[3], NA, plotting.cols[7]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)




par(mar = c(6, 5, 4, 8))
plot(wild.pca.scores[,1],
     wild.pca.scores[,2],
     type = "n", xlab = "PC1", ylab = "PC3",
     las=1, 
     main = "")

points(wild.pca.scores[wild.info$Taxon=="Col_W",1],
       wild.pca.scores[wild.info$Taxon=="Col_W",3],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(wild.pca.scores[wild.info$Taxon=="Lan_W",1],
       wild.pca.scores[wild.info$Taxon=="Lan_W",3],
       pch=22, col = "darkgreen", bg = plotting.cols[3],
       cex = 1.2)

points(wild.pca.scores[wild.info$Taxon=="Nem_W",1],
       wild.pca.scores[wild.info$Taxon=="Nem_W",3],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(wild.pca.scores[wild.info$Taxon=="Ova_W",1],
       wild.pca.scores[wild.info$Taxon=="Ova_W",3],
       pch=21, col = "brown", bg = plotting.cols[7],
       cex = 1.2)


legend("topright",
       inset = c(-0.38, 0),
       legend = c("Ar. col.", "Ag. lanc.",
                  "Ar. nem.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 22, 17, 21),
       col = c(plotting.cols[1], "darkgreen", plotting.cols[2], "brown"),
       pt.bg = c(NA, plotting.cols[3], NA, plotting.cols[7]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)



par(mar = c(6, 5, 4, 8))
plot(wild.pca.scores[,2],
     wild.pca.scores[,3],
     type = "n", xlab = "PC2", ylab = "PC3",
     las=1, 
     main = "")

points(wild.pca.scores[wild.info$Taxon=="Col_W",2],
       wild.pca.scores[wild.info$Taxon=="Col_W",3],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(wild.pca.scores[wild.info$Taxon=="Lan_W",2],
       wild.pca.scores[wild.info$Taxon=="Lan_W",3],
       pch=22, col = "darkgreen", bg = plotting.cols[3],
       cex = 1.2)

points(wild.pca.scores[wild.info$Taxon=="Nem_W",2],
       wild.pca.scores[wild.info$Taxon=="Nem_W",3],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(wild.pca.scores[wild.info$Taxon=="Ova_W",2],
       wild.pca.scores[wild.info$Taxon=="Ova_W",3],
       pch=21, col = "brown", bg = plotting.cols[7],
       cex = 1.2)


legend("topright",
       inset = c(-0.38, 0),
       legend = c("Ar. col.", "Ag. lanc.",
                  "Ar. nem.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 22, 17, 21),
       col = c(plotting.cols[1], "darkgreen", plotting.cols[2], "brown"),
       pt.bg = c(NA, plotting.cols[3], NA, plotting.cols[7]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)




par(mar = c(6, 5, 4, 8))
plot(wild.pca.scores[,1],
     wild.pca.scores[,4],
     type = "n", xlab = "PC1", ylab = "PC4",
     las=1, 
     main = "")

points(wild.pca.scores[wild.info$Taxon=="Col_W",1],
       wild.pca.scores[wild.info$Taxon=="Col_W",4],
       pch=15, col = plotting.cols[1],
       cex = 1.2)

points(wild.pca.scores[wild.info$Taxon=="Lan_W",1],
       wild.pca.scores[wild.info$Taxon=="Lan_W",4],
       pch=22, col = "darkgreen", bg = plotting.cols[3],
       cex = 1.2)

points(wild.pca.scores[wild.info$Taxon=="Nem_W",1],
       wild.pca.scores[wild.info$Taxon=="Nem_W",4],
       pch=17, col = plotting.cols[2],
       cex = 1.2)

points(wild.pca.scores[wild.info$Taxon=="Ova_W",1],
       wild.pca.scores[wild.info$Taxon=="Ova_W",4],
       pch=21, col = "brown", bg = plotting.cols[7],
       cex = 1.2)


legend("topright",
       inset = c(-0.38, 0),
       legend = c("Ar. col.", "Ag. lanc.",
                  "Ar. nem.", "Ag. ovat."),
       bty = "n",
       pch = c(15, 22, 17, 21),
       col = c(plotting.cols[1], "darkgreen", plotting.cols[2], "brown"),
       pt.bg = c(NA, plotting.cols[3], NA, plotting.cols[7]),
       pt.cex = 1.2, text.font = 3,
       y.intersp=1,
       xpd = TRUE)



#derivative 1 Loadings on PCA

wavenumbers.sg <- as.numeric(sub("X", "", colnames(wild.stand.m1)))

wild.pca.loadings <- as.data.frame(wild.pca$rotation)

plot(wavenumbers.sg,
     wild.pca.loadings[,1],
     type = "l", xlab = "wavenumbers", ylab = "PC1 loadings",
     las=1,
     main = "", xlim = c(4000, 500))

plot(wavenumbers.sg,
     wild.pca.loadings[,2],
     type = "l", xlab = "wavenumbers", ylab = "PC1 loadings",
     las=1,
     main = "", xlim = c(4000, 500))

plot(wavenumbers.sg,
     wild.pca.loadings[,3],
     type = "l", xlab = "wavenumbers", ylab = "PC1 loadings",
     las=1,
     main = "", xlim = c(4000, 500))

plot(wavenumbers.sg,
     wild.pca.loadings[,4],
     type = "l", xlab = "wavenumbers", ylab = "PC1 loadings",
     las=1,
     main = "", xlim = c(4000, 500))



#derivative 2 loadings on PCA
##error message Error in xy.coords(x, y, xlabel, ylabel, log) : 'x' and 'y' lengths differ
#cannot get these to work

wavenumbers.sg <- as.numeric(sub("X", "", colnames(wild.stand.m2)))

plot(wavenumbers.sg,
     wild.pca.loadings[,1],
     type = "l", xlab = "wavenumbers", ylab = "PC1 loadings",
     las=1,
     main = "", xlim = c(4000, 500))

plot(wavenumbers.sg,
     wild.pca.loadings[,2],
     type = "l", xlab = "wavenumbers", ylab = "PC1 loadings",
     las=1,
     main = "", xlim = c(4000, 500))

plot(wavenumbers.sg,
     wild.pca.loadings[,3],
     type = "l", xlab = "wavenumbers", ylab = "PC1 loadings",
     las=1,
     main = "", xlim = c(4000, 500))

plot(wavenumbers.sg,
     wild.pca.loadings[,4],
     type = "l", xlab = "wavenumbers", ylab = "PC1 loadings",
     las=1,
     main = "", xlim = c(4000, 500))


#first derivative
#Cluster analysis
wild.clust <- hclust(dist(wild.stand.m1), method = "average")
plot(wild.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

plot(wild.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = wild.info$Taxon)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

plot(wild.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = wild.info$Genus)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

#second derivative
#Cluster analysis
wild.clust <- hclust(dist(wild.stand.m2), method = "average")
plot(wild.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

plot(wild.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = wild.info$Taxon)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

plot(wild.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = wild.info$Genus)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

#Taxon mean cluster analysis
#first derivative
wild.stand.m1.means <- aggregate(wild.stand.m1, by = list(wild.info$Taxon),
                                      FUN = mean)
rownames(wild.stand.m1.means) <- wild.stand.m1.means[,1]
wild.stand.m1.means <- wild.stand.m1.means[,-1]

wild.stand.m1.means.clust <- hclust(dist(wild.stand.m1.means), method = "average")
plot(wild.stand.m1.means.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)


#Taxon mean cluster analysis
#second derivative
wild.stand.m2.means <- aggregate(wild.stand.m2, by = list(wild.info$Taxon),
                                      FUN = mean)
rownames(wild.stand.m2.means) <- wild.stand.m2.means[,1]
wild.stand.m2.means <- wild.stand.m2.means[,-1]

wild.stand.m2.means.clust <- hclust(dist(wild.stand.m2.means), method = "average")
plot(wild.stand.m2.means.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

